"""Provides all the data related to transports."""

TRUCKS = [
    'ACMAT',
    'AEC',
    'AIL',
    'AWD',
    'Albion',
    'Argyle',
    'Askam',
    'Astra',
    'Atkinson',
    'Austin',
    'Automiesse',
    'BMC',
    'Barkas',
    'Baron',
    'Barreiros',
    'Bean',
    'Beardmore',
    'Bedford',
    'BelAZ',
    'Berliet',
    'Berna',
    'Bernard',
    'Borgward',
    'Bristol',
    'Brossel',
    'Bucegi',
    'Büssing',
    'Caledon',
    'Carmichael',
    'Chavdar',
    'Chery',
    'Chingkangshan',
    'Citroen',
    'Commer',
    'Crossley',
    'Csepel',
    'Daewoo',
    'Daihatsu',
    'Delahaye',
    'Dennison',
    'Dodge',
    'Douglas',
    'ELBO',
    'ERF',
    'Ebro',
    'FAP',
    'FAW',
    'FBW',
    'Fargo',
    'Fiat',
    'Foden',
    'Ford',
    'Foton',
    'Fowler',
    'GA',
    'GAZ',
    'GV',
    'Garner',
    'Garrett',
    'Gaz',
    'Genoto',
    'Gilford',
    'Ginaf',
    'Grube',
    'Guy',
    'HHT',
    'HSG',
    'Halley',
    'Hallford',
    'Hanomag',
    'Hardy',
    'Haulamatic',
    'Henschel',
    'Hino',
    'Horch',
    'Hotchkiss',
    'Hyundai',
    'IFA',
    'Isuzu',
    'Iveco',
    'Jelcz',
    'Jensen',
    'Jiaotong',
    'Jiefang',
    'KAZ',
    'KMC',
    'Kaelble',
    'Kalmar',
    'Kamaz',
    'Karrier',
    'Komatsu',
    'KrAZ',
    'LAZ',
    'LIAZ',
    'Labourier',
    'Lacre',
    'Lancia',
    'Latil',
    'Leyland',
    'Loheac',
    'Lomount',
    'MAN',
    'MAZ',
    'MTN',
    'MTZ',
    'MZKT',
    'Madara',
    'Magirus',
    'Manchester',
    'Mann',
    'Maudslay',
    'Mazda',
    'McCrud',
    'Minerva',
    'Minsei',
    'Morris',
    'Mowag',
    'Multicar',
    'Multiwheeler',
    'Namco',
    'Neobus',
    'Nibus',
    'Nicolas',
    'Nissian',
    'Norde',
    'Opel',
    'Otokar',
    'Otosan',
    'Pagefield',
    'Panhard',
    'Pegaso',
    'Peugeot',
    'Praga',
    'Preslav',
    'Proctor',
    'Quest',
    'Raba',
    'Robur',
    'Roman',
    'Rotinoff',
    'Rutland',
    'SD',
    'SR',
    'Saurer',
    'Saviem',
    'Scammell',
    'Scania',
    'Seddon',
    'Sentinel',
    'Shacman',
    'Shefflex',
    'Sides',
    'Simca',
    'Sinotruk',
    'Sitom',
    'Somua',
    'Star',
    'Steyr',
    'Straussler',
    'TAM',
    'TVM',
    'TVS',
    'TVW',
    'Tata',
    'Tatra',
    'Temax',
    'Terberg',
    'Thornycroft',
    'Titan',
    'Tonar',
    'URO',
    'Unic',
    'Unimog',
    'Union',
    'Unipower',
    'Ural',
    'Vanaja',
    'Verheul',
    'Volkswagen',
    'Vomag',
    'Vulcan',
    'Willeme',
    'XCMG',
    'Yarovit',
    'Yorkshire',
    'Yuejin',
    'ZiL',
    'Zwicky',
    'ÖAF',
    'Škoda',
]

CARS = [
    'Ford Model T',
    'Volkswagen Beetle',
    'Toyota Corolla',
    'Ford Falcon',
    'Volkswagen Gol',
    'Volkswagen Santana',
    'Škoda Octavia',
    'Renault Clio',
    'Volkswagen Golf',
    'Hindustan Ambassador',
    'Fiat Uno',
    'Toyota Corolla',
    'Perodua Myvi',
    'SEAT Ibiza',
    'Volvo 200 Series',
    'Renault Symbol',
    'ZAZ Zaporozhets',
    'Morris Mini',
    'Ford F-Series',
    'Alfa Romeo Alfasud',
    'Alpine A310',
    'AMC Hornet',
    'Aston Martin DB7',
    'Autobianchi A112',
    'BMW 3 Series',
    'Buick LeSabre',
    'Bugatti Type 40',
    'Cadillac De Ville',
    'Checker Marathon',
    'Chevrolet Impala',
    'Chrysler Newport',
    'Citroën 2CV',
    'Continental Mark II',
    'Crosley',
    'DeSoto Custom',
    'De Tomaso Pantera',
    'Dodge Coronet',
    'Eagle Talon',
    'Edsel Ranger',
    'Excalibur Series II',
    'Facellia',
    'Ferrari 360',
    'Fiat Uno',
    'Ford F-Series',
    'Frazer Standard',
    'Henry J Deluxe',
    'Hindustan Ambassador',
    'Holden Commodore',
    'Honda Civic',
    'Hudson Super',
    'Imperial Crown',
    'Jaguar XJ',
    'Jeep Cherokee (XJ)',
    'Kaiser Deluxe',
    'Koenigsegg CCX',
    'Lada Riva',
    'Series/Defender',
    'Lamborghini Gallardo',
    'Lancia Ypsilon',
    'Lincoln Town Car',
    'Lotus Elise',
    'McLaren 12C',
    'Maserati Biturbo',
    'Mazda Familia',
    'Mercedes-Benz C-Class',
    'Mercury Grand Marquis',
    'Messerschmitt KR200',
    'Metropolitan',
    'Mitsubishi Lancer',
    'Nash Statesman',
    'Oldsmobile Cutlass',
    'Opel Corsa',
    'Packard Eight',
    'Peel Trident',
    'Perodua Myvi',
    'Peugeot 206',
    'Plymouth Fury',
    'Pontiac Grand Am',
    'Porsche 911',
    'Rambler Classic',
    'Renault Clio',
    'Rolls-Royce Silver Shadow',
    'Saab 900',
    'Saturn S-Series',
    'SEAT Ibiza',
    'Simca 1100',
    'Smart Fortwo',
    'Studebaker Champion',
    'Subaru Legacy',
    'Škoda Octavia',
    'Toyota Corolla',
    'Tesla Model S',
    'Trabant',
    'Volkswagen Golf',
    'Volvo 200 Series',
    'Willys 77',
    'Zaporozhets',
    'Nissan Leaf',
    'Chevrolet Impala',
    'Toyota Prius',
    'Ford F-Series',
    'Chevrolet Volt',
    'Cadillac De Ville',
    'Porsche 911 GT3 Cup',
    'Mazda RX-7',
    'Nissan Z-cars',
    'Mazda MX-5',
    'Volkswagen Type 2',
]

AIRPLANES = (
    'Airbus',
    'Boeing',
    'Tu',
)

VR_CODES = [
    'A',
    'ABH',
    'AFG',
    'AG',
    'AL',
    'AM',
    'AND',
    'ANG',
    'ARK',
    'AS',
    'AUA',
    'AUS',
    'AX',
    'AXA',
    'AZ',
    'B',
    'BD',
    'BDS',
    'BF',
    'BG',
    'BH',
    'BHT',
    'BIH',
    'BOL',
    'BR',
    'BRN',
    'BRU',
    'BS',
    'BUR',
    'BVI',
    'BW',
    'BY',
    'BZ',
    'C',
    'CAM',
    'CDN',
    'CGO',
    'CH',
    'CHN',
    'CI',
    'CL',
    'CO',
    'COM',
    'CR',
    'CV',
    'CY',
    'CYM',
    'CZ',
    'D',
    'DJI',
    'DK',
    'DOM',
    'DY',
    'DZ',
    'E',
    'EAK',
    'EAT',
    'EAU',
    'EAZ',
    'EC',
    'EIR',
    'ENG',
    'ER',
    'ES',
    'EST',
    'ET',
    'ETH',
    'F',
    'FIN',
    'FJI',
    'FL',
    'FO',
    'FSM',
    'G',
    'GB',
    'GBA',
    'GBG',
    'GBJ',
    'GBM',
    'GBZ',
    'GCA',
    'GE',
    'GH',
    'GQ',
    'GR',
    'GUY',
    'GW',
    'H',
    'HK',
    'HKJ',
    'HN',
    'HR',
    'I',
    'IL',
    'IND',
    'IR',
    'IRL',
    'IRQ',
    'IS',
    'J',
    'JA',
    'K',
    'KAN',
    'KIR',
    'KN',
    'KP',
    'KS',
    'KSA',
    'KWT',
    'KZ',
    'L',
    'LAO',
    'LAR',
    'LB',
    'LS',
    'LT',
    'LV',
    'M',
    'MA',
    'MAL',
    'MC',
    'MD',
    'MEX',
    'MGL',
    'MH',
    'MK',
    'MNE',
    'MO',
    'MOC',
    'MS',
    'MV',
    'MW',
    'N',
    'NA',
    'NAM',
    'NAU',
    'NC',
    'NEP',
    'NI',
    'NIC',
    'NL',
    'NZ',
    'OM',
    'P',
    'PA',
    'PAL',
    'PE',
    'PK',
    'PL',
    'PMR',
    'PNG',
    'PR',
    'PS',
    'PY',
    'Q',
    'RA',
    'RB',
    'RC',
    'RCA',
    'RCB',
    'RCH',
    'RG',
    'RH',
    'RI',
    'RIM',
    'RKS',
    'RL',
    'RM',
    'RMM',
    'RN',
    'RO',
    'ROK',
    'RP',
    'RSM',
    'RSO',
    'RU',
    'RUS',
    'RWA',
    'S',
    'SCO',
    'SCV',
    'SD',
    'SGP',
    'SK',
    'SLE',
    'SLO',
    'SME',
    'SMOM',
    'SN',
    'SO',
    'SOL',
    'SRB',
    'STP',
    'SUD',
    'SY',
    'SYR',
    'T',
    'TCH',
    'TG',
    'TJ',
    'TL',
    'TM',
    'TN',
    'TO',
    'TR',
    'TT',
    'TUV',
    'UA',
    'UAE',
    'USA',
    'UY',
    'UZ',
    'V',
    'VN',
    'VU',
    'WAG',
    'WAL',
    'WAN',
    'WD',
    'WG',
    'WL',
    'WS',
    'WSA',
    'WV',
    'YAR',
    'YV',
    'Z',
    'ZA',
    'ZW',
]

VRC_BY_LOCALES = {
    'cs': 'CZ',
    'da': 'DK',
    'de': 'D',
    'de-at': 'A',
    'de-ch': 'CH',
    'el': 'GR',
    'en': 'USA',
    'en-au': 'AUS',
    'en-ca': 'CDN',
    'en-gb': 'GB',
    'es': 'E',
    'es-mx': 'MEX',
    'et': 'EW',
    'fa': 'IR',
    'fi': 'FIN',
    'fr': 'F',
    'hu': 'H',
    'is': 'IS',
    'it': 'I',
    'ja': 'J',
    'kk': 'KZ',
    'ko': 'ROK',
    'nl': 'NL',
    'nl-be': 'B',
    'no': 'N',
    'pl': 'PL',
    'pt': 'P',
    'pt-br': 'BR',
    'ru': 'RUS',
    'sv': 'S',
    'tr': 'TR',
    'uk': 'UA',
    'zh': 'CHN',
}
