"""Provides all the data related to the hardware."""

RESOLUTIONS = [
    '1152x768',
    '1280x854',
    '1440x960',
    '2880x1920',
    '1024x768',
    '1152x864',
    '1280x960',
    '1400x1050',
    '1600x1200',
    '2048x1536',
    '3200x2400',
    '1280x768',
    '1280x1024',
    '2560x2048',
    '1280x720',
    '1365x768',
    '1600x900',
    '1920x1080',
    '1280x800',
    '1440x900',
    '1680x1050',
    '1920x1200',
    '2560x1600',
]

SCREEN_SIZES = [
    '14″',
    '12.1″',
    '12″',
    '14.4″',
    '15″',
    '15.7″',
    '13.3″',
    '13″',
    '17″',
    '15.4″',
    '14.1″',
]

CPU = [
    'AMD Ryzen 7 1800X',
    'AMD Ryzen 7 1700',
    'AMD Ryzen™ Threadripper™',
    'Intel® Core i3',
    'Intel® Core i5',
    'Intel® Core i7',
    'Intel® Core i9',
]

RAM_TYPES = [
    'SDRAM',
    'DDR',
    'DDR2',
    'DDR3',
    'DDR4',
]

RAM_SIZES = [
    '4GB',
    '8GB',
    '16GB',
    '32GB',
    '64GB',
]

GENERATION = [
    '2nd Generation',
    '3rd Generation',
    '4th Generation',
    '5th Generation',
    '6th Generation',
    '7th Generation',
]

CPU_MODEL_CODES = [
    '7500U',
    '7Y75',
    '7Y30',
    '7200U',
    '7500U',
    '6600K',
    '6700T',
    '6700K',
    '6600T',
    '6300T',
    '6100H',
    '6820HK',
    '6920HQ',
    '6700HQ',
    '6600U',
    '6300U',
    '6100U',
    '5775C',
    '5675C',
    '5775R',
    '5675R',
    '5575R',
    '5350H',
    '5950HQ',
    '5850HQ',
    '5750HQ',
    '5700HQ',
    '5650U',
]

CPU_CODENAMES = [
    'Ivytown',
    'Haswell',
    'Fortville',
    'Devil\'s Canyon',
    'Valley Island',
    'Broadwell',
    'Bay Trail',
    'Skylake',
    'Orchid Island',
    'Bear Ridge',
    'Cannonlake',
]

HDD_SSD = [
    '64GB SSD',
    '128GB SSD',
    '256GB SDD',
    '512GB SSD',
    '1024GB SSD',
    '256GB HDD',
    '256GB HDD(7200 RPM)',
    '256GB HDD(5400 RPM)',
    '512GB HDD',
    '512GB HDD(7200 RPM)',
    '1TB HDD',
    '1TB HDD(7200 RPM)',
    '1TB HDD + 64GB SSD',
    '2TB HDD(7200 RPM)',
    '512 GB HDD + 32GB SSD',
    '1TB HDD(7200 RPM) + 32GB SSD',
]

GRAPHICS = [
    'Intel® HD Graphics 620',
    'Intel® HD Graphics 615',
    'Intel® Iris™ Pro Graphics 580',
    'Intel® Iris™ Graphics 550',
    'Intel® HD Graphics 520',
    'Intel® Iris™ Pro Graphics 6200',
    'Intel® Iris™ Graphics 6100',
    'Intel® HD Graphics 6000',
    'Intel® HD Graphics 5300 ',
    'Intel® Iris™ Pro Graphics 5200',
    'Intel® Iris™ Graphics 5100',
    'Intel® HD Graphics 5500',
    'Intel® HD Graphics 5000',
    'Intel® HD Graphics 4600',
    'Intel® HD Graphics 4400',
    'Intel® HD Graphics 4000',
    'Intel® HD Graphics 3000',
    'NVIDIA GeForce GTX 1080',
    'NVIDIA GeForce GTX 1070',
    'NVIDIA GeForce GTX 1080',
    'NVIDIA GeForce GTX 980',
    'NVIDIA GeForce GTX 1070',
    'NVIDIA GeForce GTX 980M',
    'NVIDIA GeForce GTX 980',
    'NVIDIA GeForce GTX 970M',
    'NVIDIA GeForce GTX 880M',
    'AMD Radeon R9 M395X',
    'AMD Radeon R9 M485X',
    'AMD Radeon R9 M395',
]

MANUFACTURERS = [
    'Apple',
    'Acer',
    'Dell',
    'ASUS',
    'VAIO',
    'Lenovo',
    'HP',
    'Toshiba',
    'Sony',
    'Samsung',
    'Fujitsu',
    'Apple',
]

PHONE_MODELS = [
    'Apple iPhone 4',
    'Apple iPhone 4S',
    'Apple iPhone 5',
    'Apple iPhone 5s',
    'Apple iPhone 6',
    'Apple iPhone 6 Plus',
    'Apple iPhone 6s',
    'Apple iPhone 6s Plus',
    'Apple iPhone 7',
    'Apple iPhone 7 Plus',
    'Apple iPhone SE',
    'BlackBerry 10 Classic',
    'BlackBerry 10 Leap',
    'BlackBerry 10 P\'9982',
    'BlackBerry 10 Passport',
    'BlackBerry 10 Q10',
    'BlackBerry 10 Q5',
    'BlackBerry 10 Z10',
    'BlackBerry 10 Z3',
    'BlackBerry 10 Z30',
    'Nexus 5',
    'Nexus 5X',
    'Nexus 6',
    'Nexus 6P',
    'Nexus 7',
    'Nokia Lumia 1020',
    'Nokia Lumia 1320',
    'Nokia Lumia 1520',
    'Nokia Lumia 2520',
    'Nokia Lumia 505',
    'Nokia Lumia 510',
    'Nokia Lumia 520',
    'Nokia Lumia 525',
    'Nokia Lumia 530',
    'Nokia Lumia 610',
    'Nokia Lumia 620',
    'Nokia Lumia 625',
    'Nokia Lumia 630',
    'Nokia Lumia 635',
    'Nokia Lumia 636',
    'Nokia Lumia 638',
    'Nokia Lumia 710',
    'Nokia Lumia 720',
    'Nokia Lumia 730',
    'Nokia Lumia 735',
    'Nokia Lumia 800',
    'Nokia Lumia 810',
    'Nokia Lumia 820',
    'Nokia Lumia 822',
    'Nokia Lumia 830',
    'Nokia Lumia 900',
    'Nokia Lumia 920',
    'Nokia Lumia 925',
    'Nokia Lumia 928',
    'Nokia Lumia 930',
    'Nokia Lumia ICON',
    'Samsung GT-B7330',
    'Samsung GT-C3520',
    'Samsung GT-E1150i',
    'Samsung Galaxy',
    'Samsung Galaxy',
    'Samsung Galaxy 5',
    'Samsung Galaxy Ace 2',
    'Samsung Galaxy Ace 3',
    'Samsung Galaxy Ace 4',
    'Samsung Galaxy Active Neo',
    'Samsung Galaxy Alpha',
    'Samsung Galaxy Beam i8530',
    'Samsung Galaxy Chat',
    'Samsung Galaxy Core',
    'Samsung Galaxy Core Advance',
    'Samsung Galaxy Core LTE',
    'Samsung Galaxy Core Prime',
    'Samsung Galaxy Duos',
    'Samsung Galaxy E5',
    'Samsung Galaxy E7',
    'Samsung Galaxy Grand Prime',
    'Samsung Galaxy J',
    'Samsung Galaxy J1 Ace Neo',
    'Samsung Galaxy J1 Ace VE',
    'Samsung Galaxy J1 Mini',
    'Samsung Galaxy J5',
    'Samsung Galaxy J7 (2016)',
    'Samsung Galaxy Mega',
    'Samsung Galaxy Mega 2',
    'Samsung Galaxy Note 3',
    'Samsung Galaxy Note 3 Neo',
    'Samsung Galaxy Note 4',
    'Samsung Galaxy Note 5',
    'Samsung Galaxy Note 7',
    'Samsung Galaxy Note Edge',
    'Samsung Galaxy Note II',
    'Samsung Galaxy Note series',
    'Samsung Galaxy Pocket',
    'Samsung Galaxy Pocket 2',
    'Samsung Galaxy Pocket Duos',
    'Samsung Galaxy Pocket Neo',
    'Samsung Galaxy Pocket Plus',
    'Samsung Galaxy Portal',
    'Samsung Galaxy Prevail',
    'Samsung Galaxy R',
    'Samsung Galaxy Round',
    'Samsung Galaxy S',
    'Samsung Galaxy S 4G LTE',
    'Samsung Galaxy S Advance',
    'Samsung Galaxy S II',
    'Samsung Galaxy S III Mini',
    'Samsung Galaxy S III Neo',
    'Samsung Galaxy S Plus',
    'Samsung Galaxy S series',
    'Samsung Galaxy S6',
    'Samsung Galaxy Spica',
    'Samsung Galaxy Star',
    'Samsung Galaxy Tab series',
    'Samsung Galaxy Trend 2 Lite',
    'Samsung Galaxy W',
    'Samsung Galaxy Y',
    'Samsung Galaxy Young',
    'Samsung Galaxy Young 2',
    'Samsung Gravity series',
    'Samsung SGH-G600',
    'Samsung SGH-G800',
    'Samsung SGH-G810',
    'Sony Xperia E5',
    'Sony Xperia X',
    'Sony Xperia XA',
    'Sony Xperia XA Dual',
    'Sony Xperia XZ',
    'Sony Xperia Z5 Premium',
]
