"""Metadata of package."""

__version__ = '2.0.1'
__title__ = 'mimesis'
__description__ = 'Mimesis: mock data for developers.'
__url__ = 'https://github.com/lk-geimfari/mimesis'
__author__ = 'Likid Geimfari (Isaak Uchakaev)'
__author_email__ = 'likid.geimfari@gmail.com'
__license__ = 'MIT License'
