"""Mimesis is a Python library, which helps generate synthetic data.

Copyright (c) 2016 - 2018 Likid Geimfari (Isaak Uchakaev)
Repository: https://github.com/lk-geimfari/mimesis
Email: <likid.geimfari@gmail.com>
"""

from mimesis.providers import *

__all__ = [
    'Address',
    'BaseDataProvider',
    'BaseProvider',
    'Business',
    'ClothingSize',
    'Code',
    'Datetime',
    'Development',
    'File',
    'Food',
    'Games',
    'Hardware',
    'Internet',
    'Numbers',
    'Path',
    'Payment',
    'Person',
    'Science',
    'Structure',
    'Text',
    'Transport',
    'UnitSystem',
    'Cryptographic',

    # Has all:
    'Generic',
]
