"""Provides all the data related to the games."""

GAMING_PLATFORMS = [
    'Nintendo 64',
    'Nintendo Switch',
    'PC',
    'PlayStation 3',
    'PlayStation 4',
    'PlayStation 4 Pro',
    'PlayStation Vita',
    'Xbox 360',
    'Xbox One',
    'Xbox One S',
    'Xbox One X',
]

SCORE_PHRASES = [
    'Amazing',
    'Awful',
    'Bad',
    'Disaster',
    'Good',
    'Great',
    'Masterpiece',
    'Mediocre',
    'Okay',
    'Painful',
    'Unbearable',
]

GENRES = [
    'Action',
    'Action, Adventure',
    'Action, Compilation',
    'Action, Platformer',
    'Action, Puzzle',
    'Action, RPG',
    'Action, Simulation',
    'Action, Strategy',
    'Adventure',
    'Adventure, Adult',
    'Adventure, Adventure',
    'Adventure, Compilation',
    'Adventure, Episodic',
    'Adventure, Platformer',
    'Adventure, RPG',
    'Baseball',
    'Battle',
    'Board',
    'Card',
    'Card, Battle',
    'Compilation',
    'Compilation, RPG',
    'Educational',
    'Educational, Adventure',
    'Educational, Puzzle',
    'Fighting',
    'Fighting, Action',
    'Fighting, Compilation',
    'Fighting, Simulation',
    'Flight',
    'Flight, Action',
    'Flight, Simulation',
    'Hardware',
    'Hunting',
    'Music',
    'Music, Action',
    'Music, Adventure',
    'Music, RPG',
    'Other',
    'Other, Adventure',
    'Party',
    'Pinball',
    'Platformer',
    'Platformer, Action',
    'Platformer, Adventure',
    'Productivity',
    'Productivity, Action',
    'Puzzle',
    'Puzzle, Action',
    'Puzzle, Adventure',
    'Puzzle, Compilation',
    'Puzzle, Platformer',
    'Puzzle, RPG',
    'Puzzle, Word Game',
    'RPG',
    'RPG, Action',
    'RPG, Simulation',
    'Racing',
    'Racing, Action',
    'Shooter',
    'Shooter, Adventure',
    'Shooter, First-Person',
    'Shooter, RPG',
    'Simulation',
    'Simulation, Adventure',
    'Sports',
    'Sports, Action',
    'Sports, Baseball',
    'Sports, Compilation',
    'Sports, Fighting',
    'Sports, Golf',
    'Sports, Other',
    'Sports, Party',
    'Sports, Simulation',
    'Strategy',
    'Strategy, RPG',
    'Strategy, Simulation',
    'Trivia',
    'Virtual Pet',
    'Wrestling',
]

GAMES = [
    '007 Legends',
    '1-bit Ninja',
    '2Bit',
    '3 Heroes -- Crystal Soul',
    '3D Classics: Excitebike',
    "3D Classics: Kirby's Adventure",
    '3D Classics: TwinBee',
    '3D Classics: Urban Champion',
    '3D Classics: Xevious',
    '3D Pixel Racing',
    '4 Elements HD',
    '4 Elements II',
    '7 Days to Die',
    '80 Days',
    '99Bullets',
    '101-in-1 Explosive Megamix',
    '140',
    '1001 BlockBusters',
    '1001 Spikes',
    '1942 (Arcade)',
    "1950's Lawnmower Kids",
    '1979 Revolution',
    '2014 FIFA World Cup Brazil',
    '10000000',
    'Infinity Field HD',
    'Infinity Field',
    'Infinity Blade III',
    'Infinity Blade II',
    '#IDARB',
    'A Bird Story',
    'A Game of Thrones: Genesis',
    'A Valley Without Wind',
    'A Virus Named Tom',
    'A.R.E.S.: Extinction Agenda',
    'AFL Live',
    'ARC Squadron',
    "Aaru's Awakening",
    'Abyss Odyssey',
    'Abzu',
    'Academy: Checkers',
    'Ace Combat Assault Horizon',
    'Ace Combat Assault Horizon Legacy',
    'Ace of Spades',
    'Achron',
    'Adr1ft',
    'Adr1ft [VR Edition]',
    'Adventure Island',
    "Adventure Time: Explore the Dungeon Because I Don't Know!",
    "Adventure Time: Hey Ice King! Why'd You Steal Our Garbage?",
    'AfterZoom',
    'Afterfall: Insanity',
    'Age of Empires Online',
    'Age of Wonders III',
    'Age of Wushu',
    'Air Conflicts: Secret Wars',
    'Air Conflicts: Vietnam',
    'Air Penguin',
    'AirBuccaneers',
    'AirMech Arena',
    'Akai Katana',
    'Akaneiro: Demon Hunters',
    'Akimi Village',
    'Alan Wake',
    "Alan Wake's American Nightmare",
    "Alekhine's Gun",
    'Alice: Madness Returns',
    'Alien Breed 3: Descent',
    'Alien Rage',
    'Alien Zombie Megadeath',
    'Alien: Isolation',
    'Aliens: Colonial Marines',
    'Aliens: Infestation',
    'All Zombies Must Die',
    'Alleyway',
    'Amnesia: A Machine for Pigs',
    'Among the Sleep',
    'Amplitude',
    'Amy',
    'Analogue: A Hate Story',
    'Anarchy Reigns',
    'Ancient Space',
    'Angry Birds',
    'Angry Birds 2',
    'Angry Birds Go!',
    'Angry Birds Rio',
    'Angry Birds Space',
    'Angry Birds Star Wars',
    'Angry Birds Trilogy',
    'Angry Business Man',
    'Anima: Ark of Sinners',
    'Animal Crossing: Amiibo Festival',
    'Animal Crossing: Happy Home Designer',
    'Animal Crossing: New Leaf',
    'Anna',
    'Anno 2070',
    'Anno 2205',
    'Anomaly 2',
    'Anomaly: Warzone Earth',
    'Another World',
    'Another World: 20th Anniversary Edition',
    'Anthill: Tactical Trail Defense',
    'Antichamber',
    'Apotheon',
    'Apox',
    'Apple Jack 2',
    'AquaPazza',
    'Ar tonelico Qoga: Knell of Ar Ciel',
    'Arcade Essentials',
    'ArmA III',
    'Armello',
    'Armored Core V',
    'Armored Core: Verdict Day',
    'Army Corps of Hell',
    'Army of Darkness: Defense',
    "Army of Two: The Devil's Cartel",
    'Art Academy: Lessons for Everyone',
    'Ash',
    'Ashes of Singularity',
    'Asphalt 3D',
    'Asphalt 7: Heat',
    'Asphalt Injection',
    "Assassin's Creed Brotherhood: The Da Vinci Disappearence",
    "Assassin's Creed Chronicles: China",
    "Assassin's Creed Chronicles: India",
    "Assassin's Creed Chronicles: Russia",
    "Assassin's Creed III",
    "Assassin's Creed III -- The Tyranny of King Washington",
    "Assassin's Creed III: Liberation",
    "Assassin's Creed IV: Black Flag",
    "Assassin's Creed IV: Black Flag -- Freedom Cry",
    "Assassin's Creed Liberation HD",
    "Assassin's Creed Pirates",
    "Assassin's Creed Recollection",
    "Assassin's Creed Syndicate",
    "Assassin's Creed Unity",
    "Assassin's Creed Unity -- Dead Kings",
    "Assassin's Creed: Brotherhood",
    "Assassin's Creed: Revelations",
    'Assassin’s Creed Rogue',
    'Assault Android Cactus',
    'Assetto Corsa',
    "Asura's Wrath",
    'Atelier Ayesha: The Alchemist of Dusk',
    'Atelier Escha & Logy: Alchemist of Dusk Sky',
    'Atelier Meruru: The Apprentice of Arland',
    'Atelier Totori Plus: The Adventurer of Arland',
    'Atelier Totori: The Adventurer of Arland',
    'Atom Zombie Smasher',
    'Attack of the Friday Monsters: A Tokyo Tale',
    'Attack on Titan',
    'Attack on Titan: Humanity in Chains',
    'Audiosurf 2',
    'Auditorium',
    'Avengers Initiative',
    'Avenging Spirit',
    'Awesomenauts',
    'Aww, Eggplant',
    'Axiom Verge',
    'Aya and the Cubes of Light',
    'Azure Striker: Gunvolt',
    'B Team - Episode 2: Ice & Venom',
    'Babel Rising',
    'Back to the Future: The Game',
    "Back to the Future: The Game -- Episode 1: It's About Time",
    'Back to the Future: The Game -- Episode 2: Get Tannen!',
    'Back to the Future: The Game -- Episode 3: Citizen Brown',
    'Back to the Future: The Game -- Episode 4: Double Visions',
    'Back to the Future: The Game -- Episode 5: Outatime',
    'BackStab',
    'Backbreaker Vengeance',
    'Bad Piggies',
    "Baldur's Gate -- Enhanced Edition",
    "Baldur's Gate II -- Enhanced Edition",
    'Balloon Kid',
    'Banana Kong',
    'BandFuse: Rock Legends',
    'Bangai-O HD: Missile Fury',
    'Banished',
    'Baseball',
    'Basement Crawl',
    'Bastion',
    'Batman: Arkham City',
    'Batman: Arkham City -- Armored Edition',
    "Batman: Arkham City -- Harley Quinn's Revenge",
    'Batman: Arkham City Lockdown',
    'Batman: Arkham Knight',
    'Batman: Arkham Knight -- Batgirl: A Matter of Family',
    "Batman: Arkham Knight -- Catwoman's Revenge",
    'Batman: Arkham Origins',
    'Batman: Arkham Origins -- Cold, Cold Heart',
    'Batman: Arkham Origins Blackgate',
    'Batman: Arkham Origins Blackgate -- Deluxe Edition',
    'Batman: The Telltale Series -- Episode 1: Realm of Shadows',
    'Batman: The Telltale Series -- Episode 2: Children of Arkham',
    'Battle Princess of Arcadias',
    'Battle of the Elements',
    'Battle: Los Angeles',
    'BattleBlock Theater',
    'Battleborn',
    'Battlefield 3',
    'Battlefield 4',
    'Battlefield Hardline',
    'Battlefield 1',
    'Battlefleet Gothic: Armada',
    'Battleheart',
    'Bayonetta 2',
    'Beat Hazard Ultra',
    'Beat Sneak Bandit',
    'Beatdown!',
    'Before the Echo',
    'Bejeweled 3',
    'Bejeweled Blitz Live',
    'Betrayer',
    'Beyond Eyes',
    'Beyond Good & Evil HD',
    'Beyond: Two Souls',
    "Bientot L'ete",
    'Big Bass Arcade',
    'Big Town Shoot Out',
    'Bike Baron',
    'Binary Domain',
    'BioShock',
    'BioShock Infinite',
    'BioShock: The Collection',
    'Bionic Commando',
    'Bionic Commando Rearmed 2',
    'Bioshock Infinite: Burial at Sea -- Episode One',
    'Bioshock Infinite: Burial at Sea -- Episode Two',
    'Bird Zapper!',
    'Bit.Trip Complete',
    'Bit.Trip Flux',
    'Bit.Trip Presents: Runner 2 Future Legend of Rhythm Alien',
    'Bit.Trip Runner',
    'Bit.Trip Saga',
    'Black Knight Sword',
    'Black Mirror III: Final Fear',
    'Black Prophecy',
    'Black Tiger',
    'Blackguards',
    'Blackguards 2',
    'Blacklight: Retribution',
    'Blackwater',
    'Bladeslinger: Episode 1',
    'Blaster Master: Enemy Below',
    'BlazBlue: Chrono Phantasma',
    'BlazBlue: Continuum Shift Extend',
    'BlazBlue: Continuum Shift II',
    'Bleach: Soul Resurreccion',
    'Blockado: Puzzle Island',
    'Blocks That Matter',
    'Blood Bowl II',
    'BloodRayne: Betrayal',
    'Bloodborne',
    'Bloodborne: The Old Hunters',
    'Bloodforge',
    'Bloodline Champions',
    'Bloons Tower Defense',
    'Blue Estate',
    'Boardwalk Ball Toss',
    'Bobby Carrot Forever',
    'Body and Brain Connection',
    'Bodycount',
    'Bomberman Hero',
    'Bombshell',
    'Boom Beach',
    'Borderlands 2',
    "Borderlands 2: Captain Scarlett and her Pirate's Booty",
    'Borderlands 2: How Marcus Saved Mercenary Day',
    'Borderlands 2: Mad Moxxi and the Wedding Day Massacre',
    "Borderlands 2: Mr. Torgue's Campaign of Carnage",
    "Borderlands 2: Sir Hammerlock's Big Game Hunt",
    "Borderlands 2: T.K. Baha's Bloody Harvest",
    "Borderlands 2: Tiny Tina's Assault on Dragon Keep",
    'Borderlands Legends',
    'Borderlands: The Handsome Collection',
    'Borderlands: The Pre-Sequel',
    'Borderlands: The Pre-Sequel -- Claptastic Voyage',
    'Botanicula',
    'Boulder Dash-XL',
    'Bound by Flame',
    'BoxBoxBoy!',
    'BoxBoy!',
    'Brain Age: Concentration Training',
    'Bravely Default',
    'Bravely Second: End Layer',
    'Brawl Brothers',
    'Breach',
    'Break Tactics',
    'Breakeroids',
    'Bridge',
    'Bring Me Sandwiches!!',
    'Brink',
    'Broforce',
    'Broken Age: Act 1',
    'Broken Age: Act 2',
    'Brothers: A Tale of Two Sons',
    "Bugs'N'Balls",
    'Build-A-Lot',
    'Bulletstorm',
    'Bumpy Road',
    'BurgerTime Deluxe',
    'BurgerTime World Tour',
    'Burn the City',
    'Burn the Rope',
    'Burnout Crash',
    'Bust-A-Move Universe',
    'Cafeteria Nipponica',
    'Cake Ninja',
    'Calculator',
    'Call of Duty: Advanced Warfare',
    'Call of Duty: Black Ops Declassified',
    'Call of Duty: Black Ops II',
    'Call of Duty: Black Ops III',
    'Call of Duty: Ghosts',
    'Call of Duty: Modern Warfare 3',
    'Call of Duty: Strike Team',
    'Call of Juarez: Gunslinger',
    'Call of Juarez: The Cartel',
    'Capsized',
    'Captain America: Super Soldier',
    'Captain Toad: Treasure Tracker',
    'Cardboard Castle',
    'Cargo! The Quest for Gravity',
    'Carmageddon: Max Damage',
    'Carmen Sandiego Adventures in Math: The Big Ben Burglary',
    'Carmen Sandiego Adventures in Math: The Lady Liberty Larceny',
    'Carnival Games: Monkey See, Monkey Do',
    'Carnivores: Dinosaur Hunter HD',
    'Cars 2',
    'Cartoon Network: Punch Time Explosion',
    'Cartoon Network: Punch Time Explosion XL',
    "Casey's Contraptions",
    'Castle Conqueror -- Against',
    'Castle Conqueror -- Heroes',
    'Castle Conqueror -- Revolution',
    'Castle of Illusion Starring Mickey Mouse',
    'CastleStorm',
    'Castlevania: Harmony of Despair',
    'Castlevania: Lords of Shadow 2',
    'Castlevania: Lords of Shadow -- Mirror of Fate',
    'Catherine',
    'Catrap',
    'Cave Story 3D',
    'Chantelise: A Tale of Two Sisters',
    'Chaos Heroes Online',
    'Chaos Rings II',
    'Charlie Murder',
    'Chasing Aurora',
    'Chibi-Robo!: Zip Lash',
    'Chicken Balls',
    'Child of Eden',
    'Child of Light',
    'Chime Super Deluxe',
    'Chivalry: Deadliest Warrior',
    'Chivalry: Medieval Warfare',
    'Choplifter HD',
    'Christmas Wonderland',
    'Chronicles of Vampires: Origins',
    'Chrono Trigger',
    'Chronos',
    'Cities in Motion',
    'Cities in Motion 2',
    'Cities: Skylines',
    'Cities: Skylines -- After Dark',
    'Citizens of Earth',
    'City of Secrets',
    'Closure',
    'Cloudberry Kingdom',
    'Clumsy Bob',
    'Cobalt',
    'Code Name S.T.E.A.M. -- Strike Team Eliminating the Alien Menace',
    'Code of Princess',
    'Colors! 3D',
    'Colour Bind',
    'Combat of Giants: Dinosaurs 3D',
    'Come On! Heroes',
    "Comedy Central's Indecision Game",
    'Commando (Arcade)',
    'Company of Heroes 2',
    'Company of Heroes 2: Ardennes Assault',
    'Company of Heroes 2: The British Forces',
    'Conduit 2',
    'Consortium',
    'Continue?9876543210',
    'Continuity 2',
    'Contrast',
    'Contre Jour',
    'Corpse Party',
    'Corpse Party: Book of Shadows',
    'Cortex Command',
    'Costume Quest',
    'Costume Quest 2',
    'Counter-Strike: Global Offensive',
    'Counterspy',
    'Cover Orange',
    'Cowboys & Aliens: Silver City Defense',
    'Craft the World',
    'Crasher',
    'Crashmo',
    'Crazy Hamster',
    'Crazy Machines Elements',
    'Crazy Taxi',
    'Crimson Dragon',
    'Crimsonland',
    'Critical Mass',
    'Crusader Kings II',
    'Crypt of the Necrodancer',
    'Crysis',
    'Crysis 2',
    'Crysis 3',
    'Crystal Caverns of Amon-Ra',
    'Cthulhu Saves the World',
    'Cubic Ninja',
    'Cut The Rope 2',
    'Cut The Rope: Experiments',
    'Cut the Rope',
    'D4',
    'DC Universe Online',
    'DCS: A-10C Warthog',
    'Dance Central 2',
    'Dance Central 3',
    'Dance Central Spotlight',
    'DanceDanceRevolution',
    'Dangerous Golf',
    'Darius Twin',
    'Dark',
    'Dark Lords',
    'Dark Souls',
    'Dark Souls (Prepare to Die Edition)',
    'Dark Souls II',
    'Dark Souls II: Crown of the Old Iron King',
    'Dark Souls II: Crown of the Sunken King',
    'Dark Souls III',
    'Darkest Dungeon',
    'Darksiders II',
    'Darksiders II: Deathinitive Edition',
    'Darkspore',
    'Darkstalkers Resurrection',
    'Datura',
    'Day of the Tentacle: Remastered',
    'Daylight',
    'Daytona USA',
    'Dead Block',
    'Dead Island',
    'Dead Island Riptide',
    'Dead Island: Definitive Collection',
    "Dead Man's Draw",
    'Dead Nation: Apocalypse Edition',
    'Dead Rising 2: Off the Record',
    'Dead Rising 3',
    'Dead Rising Triple Pack',
    'Dead Space 2',
    'Dead Space 2 (Limited Edition)',
    'Dead Space 2: Severed',
    'Dead Space 3',
    'Dead Space 3: Awakened',
    'Dead Space Extraction',
    'Dead Space [mobile version]',
    'Dead Star',
    'Dead State',
    'Dead or Alive 5',
    'Dead or Alive 5: Last Round',
    'Dead or Alive Dimensions',
    'Deadfall Adventures',
    'Deadliest Warrior: Legends',
    'Deadlight',
    "Deadly Premonition: The Director's Cut",
    'Deadpool',
    'Dear Esther',
    'Death Rally',
    'Defenders of Ardania',
    'Defense Grid 2',
    'Defense of the Middle Kingdom',
    'Defiance',
    'Defy Gravity Extended',
    'Delbo',
    "Demon's Score",
    'Depth',
    'Derrick the Deathfin',
    'Destiny',
    'Destiny: House of Wolves',
    'Destiny: The Dark Below',
    'Destiny: The Taken King',
    'Deus Ex: Human Revolution',
    "Deus Ex: Human Revolution -- Director's Cut",
    'Deus Ex: Human Revolution -- The Missing Link',
    'Deus Ex: Mankind Divided',
    'Deus Ex: The Fall',
    'Device 6',
    'Devil Daggers',
    'Devil May Cry 4 -- Special Edition',
    'Devil May Cry 4 Refrain',
    'Devil May Cry HD Collection',
    'Devil Summoner: Soul Hackers',
    "Devil's Attorney",
    "Devil's Third",
    'Diablo III',
    'Diablo III: Reaper of Souls',
    'Diablo III: Ultimate Evil Edition',
    'Diabolical Pitch',
    'Diaspora: Shattered Armistice',
    "Dillon's Rolling Western",
    "Dillon's Rolling Western: The Last Ranger",
    'Dino D-Day',
    'Dirt 3',
    'Dirt Rally',
    'Dirt Showdown',
    'Disgaea 3: Absence of Detention',
    'Disgaea 4: A Promise Unforgotten',
    'Disgaea 5: Alliance of Vengeance',
    'Disgaea D2: A Brighter Darkness',
    'Dishonored',
    'Dishonored: Definitive Edition',
    'Dishonored: The Brigmore Witches',
    'Dishonored: The Knife of Dunwall',
    'Disney Epic Mickey 2: The Power of Two',
    'Disney Epic Mickey: Power of Illusion',
    'Disney Fantasia: Music Evolved',
    'Disney Infinity',
    'Disney Infinity -- PC Game',
    'Disney Infinity: 2.0 Edition -- Marvel Super Heroes',
    'Disney Infinity: 2.0 Edition -- Toy Box Starter Pack',
    'Disney Infinity: 3.0 Edition',
    'Disney Universe',
    'Dissidia 012 Final Fantasy',
    'Divekick',
    'Divinity II: The Dragon Knight Saga',
    'Divinity: Dragon Commander',
    'Divinity: Original Sin',
    'Divinity: Original Sin -- Enhanced Edition',
    'DmC: Devil May Cry',
    'DmC: Devil May Cry -- Definitive Edition',
    'Doctor Who: The Eternity Clock',
    'DodoGo! Robo',
    'Doki-Doki Universe',
    'Dokuro',
    'Dollar Dash',
    'Don Bradman Cricket',
    'Don Bradman Cricket 14',
    "Don't Starve",
    'Donkey Kong',
    'Donkey Kong Country Returns 3D',
    'Donkey Kong Country: Tropical Freeze',
    'Doodle Fit',
    'Doom',
    'Doom 3: BFG Edition',
    'DotMan',
    'Dota 2',
    'Double Bloob',
    'Double Dragon',
    'Double Dragon: Neon',
    'Dr. Luigi',
    'Dragon Age II',
    'Dragon Age II -- Legacy',
    'Dragon Age II -- Mark of the Assassin',
    'Dragon Age: Inquisition',
    'Dragon Age: Inquisition -- Jaws of Hakkon',
    'Dragon Age: Inquisition -- The Descent',
    'Dragon Age: Inquisition -- Trespasser',
    'Dragon Ball Xenoverse',
    'Dragon Ball Z: Battle of Z',
    'Dragon Ball Z: Ultimate Tenkaichi',
    'Dragon Fantasy Book II',
    'Dragon Nest',
    'Dragon Quest Heroes',
    'Dragon Quest Monsters: Joker 2',
    'Dragon Quest VI: Realms of Revelation',
    'Dragon Quest VII: Fragments of the Forgotten Past',
    "Dragon's Crown",
    "Dragon's Dogma",
    "Dragon's Dogma: Dark Arisen",
    "Dragon's Prophet",
    'Drakengard 3',
    "Drakengard 3 (Collector's Edition)",
    'Drakerider',
    'Dream Track Nation',
    'Dream Trigger 3D',
    'Dreamcast Collection',
    'Dreamfall Chapters',
    'Driveclub',
    'Driver: San Francisco',
    'DuckTales Remastered',
    'Duke Nukem Forever',
    'Dungelot',
    'Dungeon Defenders',
    'Dungeon Hunter 4',
    'Dungeon Hunter: Alliance',
    'Dungeon Siege III',
    'Dungeon Twister',
    'Dungeon Village',
    'Dungeon of the Endless',
    'Dungeonland',
    'Dungeons',
    'Dungeons 2',
    'Dungeons & Dragons: Chronicles of Mystara',
    'Dungeons of Dredmor',
    'Dust 514',
    'Dust: An Elysian Tail',
    'Dustforce',
    'Dyad',
    'Dying Light',
    'Dying Light: The Following',
    'Dynasty Warriors 7',
    'Dynasty Warriors 7 Xtreme Legends',
    'Dynasty Warriors 7: Empires',
    'Dynasty Warriors 8',
    'Dynasty Warriors Next',
    'Dynasty Warriors: Gundam 3',
    'Dynasty Warriors: Gundam Reborn',
    'E.Y.E.: Divine Cybermancy',
    'EA Sports UFC',
    'EA Sports UFC 2',
    'ESPN Sports Connection',
    'Early Bird',
    'Earth Defense Force 2025',
    'EarthBound',
    'Earthbound Beginnings',
    'Edge of Nowhere',
    "Edna & Harvey: Harvey's New Eyes",
    'El Shaddai: Ascension of the Metatron',
    'Elder Scrolls Online: Tamriel Unlimited',
    'Elite Forces: Unit 77',
    'Elite: Dangerous',
    'Endless Legend',
    'Endless Space',
    'Enemy Front',
    'Enter the Gungeon',
    'Entwined',
    'Epoch',
    'Escape Dead Island',
    'Escape Goat',
    'Escape Plan',
    'Escape Trick: Convenience Store',
    'Escape Trick: Ninja Castle',
    'EscapeVektor: Chapter 1',
    'Ether One',
    'Etrian Odyssey 2 Untold: The Fafnir Knight',
    'Etrian Odyssey IV: Legends of the Titan',
    'Etrian Odyssey Untold: The Millennium Girl',
    'Eufloria',
    'Europa Universalis IV',
    'Everybody Dance',
    'Everybody’s Gone to the Rapture',
    'Evolve',
    'Exed Exes (Arcade)',
    'Expand',
    'Explodemon!',
    'Extreme Hangman 2',
    'F1 2011',
    'F1 2012',
    'F1 2013',
    'F1 2015',
    'F1 2016',
    'F1 Race Stars',
    'F.E.A.R. 3',
    'FAST Racing Neo',
    'FIFA 14',
    'FIFA 15',
    'FIFA 16',
    'FIFA 17',
    'FIFA Soccer 12',
    'FIFA Soccer 12 [3DS Edition]',
    'FIFA Soccer 13',
    'FIFA Soccer [PlayStation Vita edition]',
    'FIFA Street',
    'FTL: Faster Than Light',
    'Fable Anniversary',
    'Fable Heroes',
    'Fable III',
    "Fable III: Traitor's Keep",
    'Fable: The Journey',
    'Faery: Legends Of Avalon',
    'Fahrenheit: Indigo Prophecy Remastered',
    'Fairy Fencer F',
    'Fallen Enchantress',
    'Fallen Enchantress: Legendary Heroes',
    'Fallout 4',
    'Fallout 4: Automatron',
    'Fallout 4: Contraptions',
    'Fallout 4: Far Harbor',
    'Fallout 4: Nuka World',
    'Fallout 4: Vault-Tec Workshop',
    'Fallout 4: Wasteland Workshop',
    'Fallout Shelter',
    'Fallout: New Vegas -- Dead Money',
    'Fallout: New Vegas -- Honest Hearts',
    'Fallout: New Vegas -- Lonesome Road',
    'Fallout: New Vegas -- Old World Blues',
    'Family Guy: Back to the Multiverse',
    'Fantastic Pets',
    'Fantasy Life',
    'Far Cry 3',
    'Far Cry 3: Blood Dragon',
    'Far Cry 4',
    'Far Cry 4: Valley of the Yetis',
    'Far Cry Primal',
    'Farm Frenzy',
    'Farming Simulator 2013',
    'Fast & Furious: Showdown',
    'Fatal Frame: Deep Crimson Butterfly',
    'Fatal Frame: Maiden of the Black Water',
    'Fates Forever',
    'Faxanadu',
    'Feed Me Oil',
    'Fenix Rage',
    'Fez',
    'Fieldrunners 2',
    'Fight Night Champion',
    'Fighter Within',
    'Final Fantasy Dimensions',
    'Final Fantasy Explorers',
    'Final Fantasy III (SNES)',
    'Final Fantasy IV: The Complete Collection',
    'Final Fantasy Type-0 HD',
    'Final Fantasy X / X-2 HD Remaster',
    'Final Fantasy X / X-2 HD Remaster (Limited Edition)',
    'Final Fantasy XIII-2',
    'Final Fantasy XIV Online: A Realm Reborn',
    'Final Fantasy XIV Online: Heavensward',
    'Final Fantasy: All The Bravest',
    'Final Fantasy: Record Keeper',
    'Final Fight',
    'Fire Emblem Awakening',
    'Fire Emblem Fates: Birthright',
    'Fire Emblem Fates: Conquest',
    'Fire Emblem Fates: Revelation',
    'Firefall',
    'Firewatch',
    'Fish Out of Water',
    'Fish Tank',
    'Fishing Resort',
    "Fist of the North Star: Ken's Rage 2",
    'Flappy Bird',
    'Flashback',
    'Flight Control',
    'Floe: A Little Bear Needs Your Help',
    'Flower',
    'Fluidity: Spin Cycle',
    'Food Processing',
    'Foosball 2012',
    'Football Manager 2012',
    'Football Manager 2013',
    'Football Manager 2014',
    'Football Manager 2015',
    'Football Manager Classic 2014',
    'Forge',
    'Fortix 2',
    'Fortune Street',
    'Forza Horizon',
    'Forza Horizon 2',
    'Forza Horizon 2 Presents Fast & Furious',
    'Forza Horizon 3',
    'Forza Motorsport 4',
    'Forza Motorsport 5',
    'Forza Motorsport 6',
    'Fossil Fighters: Champions',
    'Fray',
    'Freakyforms Deluxe: Your Creations, Alive!',
    'Freakyforms: Your Creations, Alive!',
    'Freedom Wars',
    'From Dust',
    'Frozen Cortex',
    'Frozen Synapse',
    'Frozen Synapse Prime',
    'Fru',
    'Fruit Ninja Kinect',
    'Fruit Ninja: Puss in Boots',
    'Full House Poker',
    'Funk of Titans',
    'Funky Barn',
    'Funky Smugglers',
    'Furi',
    'Furry Legends: Beginnings',
    'Fuse',
    'Fusion: Genesis',
    'GO Series: Fishing Resort',
    'Gabriel Knight: Sins of the Fathers -- 20th Anniversary Edition',
    "Gabrielle's Ghostly Groove 3D",
    'Galactic Civilizations III',
    'Galaga Legions DX',
    'Galak-Z',
    'Game & Wario',
    'Game & Watch Gallery',
    'Game of Thrones',
    'Game of Thrones: Episode 1 -- Iron From Ice',
    'Game of Thrones: Episode 2 -- The Lost Lords',
    'Game of Thrones: Episode 3 -- The Sword in the Darkness',
    'Game of Thrones: Episode 4 -- Sons of Winter',
    'Game of Thrones: Episode 5 -- A Nest Of Vipers',
    'Game of Thrones: Episode 6 -- The Ice Dragon',
    "Gargoyle's Quest",
    'Garshasp',
    'Gatling Gears',
    'Gauntlet',
    'Gauntlet: Slayer Edition',
    'Gears',
    'Gears of War 3',
    "Gears of War 3: Raam's Shadow",
    'Gears of War: Judgment',
    'Gears of War: Ultimate Edition',
    'Gemini Rue',
    'Gemini: Heroes Reborn',
    'Gesundheit',
    'Get Outta My Galaxy',
    'Gettysburg: Armored Warfare',
    'Ghost Mania',
    'Ghost Trick: Phantom Detective',
    'Ghostbusters',
    'Ghostbusters: Sanctum of Slime',
    "Ghosts 'N Goblins (Arcade)",
    'Girls Like Robots',
    'Glare',
    'Glory Days: Tactical Defense',
    'Gnomz',
    'Go Fetch! 2',
    'Go Series: Portable Shrine Wars',
    'Go Vacation',
    'Go! Go! Kokopolo: Harmonious Forest Revenge',
    'Goat Simulator',
    'God Mode',
    'God of War Collection',
    'God of War III Remastered',
    'God of War Origins',
    'God of War: Ascension',
    'Gods & Heroes: Rome Rising',
    'Gods Eater Burst',
    'Gods Will Be Watching',
    'Godzilla',
    'Golden Axe II',
    'GoldenEye 007: Reloaded',
    'Golf',
    'Gone Home',
    'Gotham City Impostors',
    'Gran Turismo 6',
    'Grand Prix Story',
    'Grand Slam Tennis 2',
    'Grand Theft Auto III',
    'Grand Theft Auto V',
    'Grand Theft Auto: San Andreas',
    'Grand Theft Auto: Vice City',
    'Gravity Ghost',
    'Gravity Guy 2',
    'Gravity Rush',
    'Gray Matter',
    'Great Big War Game',
    'Green Lantern: Rise of the Manhunters',
    'Grey Goo',
    'Grid 2',
    'Grid Autosport',
    'Grim Dawn',
    'Grim Fandango Remastered',
    'Groove Coaster',
    'Grow Home',
    'Grow Up',
    'Guacamelee!',
    'Guacamelee! Super Turbo Championship Edition',
    'Guardian Heroes',
    'Guardians of Middle-earth',
    'Guild Wars 2',
    'Guild Wars 2: Heart of Thorns',
    'Guild of Dungeoneering',
    'Guilty Gear XX Accent Core Plus',
    'Guilty Gear XX Accent Core Plus R',
    'Guilty Gear Xrd Sign',
    'Guitar Hero Live',
    'Gun Commando',
    'Guncraft',
    'Gunman Clive',
    'Gunpoint',
    'Guns of Icarus Online',
    'HTC Vive',
    "Hack 'n' Slash",
    'Half-Minute Hero: Super Mega Neo Climax Edition',
    'Halloween: Trick or Treat',
    'Halo 3: ODST [The Master Chief Collection]',
    'Halo 4',
    'Halo 4 (Limited Edition)',
    'Halo 5: Guardians',
    'Halo: Combat Evolved Anniversary',
    'Halo: Spartan Assault',
    'Halo: Spartan Strike',
    'Halo: The Master Chief Collection',
    "Hamilton's Great Adventure",
    'Hand of Fate',
    'Happy Action Theater',
    'Happy Wars',
    'Hard Corps: Uprising',
    'Hard Reset',
    'Hard West',
    'Hardware: Rivals',
    'HarmoKnight',
    'Harry Potter and the Deathly Hallows: Part 2',
    'Harvest Moon DS: The Tale of Two Towns',
    'Harvest Moon: A New Beginning',
    'Hatoful Boyfriend',
    'He-Man: The Most Powerful Game in the Universe',
    'Hearthstone: Heroes of WarCraft',
    'Hearts Spades Euchre',
    'Hearts of Iron IV',
    'Heavy Rain',
    'Hector: Badge of Carnage -- Episode 1: We Negotiate with Terrorists',
    'Hector: Badge of Carnage -- Episode 2',
    'Hector: Badge of Carnage -- Episode 3: Beyond Reasonable Doom',
    'Hell Yeah! Wrath of the Dead Rabbit',
    'Helldivers',
    'Her Story',
    'Hero Academy',
    'Heroes of Ruin',
    'Heroes of the Storm',
    'Hitman Go',
    'Hitman HD Trilogy',
    'Hitman: Absolution',
    'Hitman: Episode 1',
    'Hitman: Episode 2',
    'Hitman: Episode 3',
    'Hitman: Episode 4',
    'Hoard',
    'Hobo with a Shotgun',
    'Hohokum',
    'Hole In The Wall',
    'Hollywood Squares',
    'Home: A Unique Horror Adventure',
    'Homefront',
    'Homefront: The Revolution',
    'Hometown Story',
    'Homeworld Remastered Collection',
    'Homeworld: Deserts of Kharak',
    'Hoodwink',
    'Horizon',
    'Horizon Riders',
    'Horn',
    'Hot Shots Golf: World Invitational',
    'Hot Shots Shorties -- Bundle Pack',
    'Hot Springs Story',
    'Hotline Miami',
    'Hotline Miami 2: Wrong Number',
    'House M.D. -- Episode 2: Blue Meanie',
    'House M.D. -- Episode 3: Skull and Bones',
    'House M.D. -- Episode 4: Crashed',
    'House M.D. -- Episode 5: Under the Big Top',
    'How to Survive',
    'Human Fall Flat',
    "Hunted: The Demon's Forge",
    'Hustle Kings',
    'Hybrid',
    'Hydrophobia: Prophecy',
    'Hyper Light Drifter',
    'Hyperdimension Neptunia',
    'Hyperdimension Neptunia Re:Birth 1',
    'Hyperdimension Neptunia Victory',
    'Hyperdimension Neptunia: Producing Perfection',
    'Hyrule Warriors',
    'Hyrule Warriors Legends',
    'Hysteria Project 2',
    'I Am Alive',
    'I Am Bread',
    'I Am Setsuna',
    'IL-2 Sturmovik: Cliffs of Dover',
    'Ibb & Obb',
    'Ikachan',
    'Ilomilo',
    'Impossible Road',
    'InMomentum',
    'Inazuma Eleven',
    'Incredipede',
    'Infamous 2',
    'Infamous: Festival of Blood',
    'Infamous: First Light',
    'Infamous: Second Son',
    'Infestation: Survivor Stories',
    'Infinite Crisis',
    'Injustice: Gods Among Us',
    'Injustice: Gods Among Us -- Ultimate Edition',
    'Insanely Twisted Shadow Planet',
    'Inside',
    'Inside a Star-Filled Sky',
    'Insurgency',
    'Into the Dead',
    'Inversion',
    'Invisible Inc.',
    'Iron Brigade',
    'Iron Man 3: The Official Game',
    'J-Stars Victory VS.+',
    'Jak and Daxter Collection',
    'Jamestown: Legend of the Lost Colony',
    "Jazz: Trump's Journey",
    'Jazzpunk',
    'JellyCar 2',
    "Jeremy McGrath's Offroad",
    "Jerry Rice & Nitus' Dog Football",
    'Jet Set Go',
    'Jet Set Radio',
    'Jetpack Joyride',
    'Jewel Keepers: Easter Island',
    'Jikandia: The Timeless Land',
    "JoJo's Bizarre Adventure HD",
    "JoJo's Bizarre Adventure: All Star Battle",
    'Joe Danger',
    'Joe Danger Infinity',
    'Joe Danger: Special Edition',
    'Joe Danger: The Movie',
    'Jonah Lomu Rugby Challenge',
    'Jotun',
    'Journey',
    'Jurassic Park: The Game',
    'Just Cause 3',
    'Just Dance 3',
    'Just Dance 4',
    'Just Dance 2014',
    'Just Dance 2015',
    'Just Jam',
    'Just SING! 80s Collection',
    'Just SING! Christmas Vol. 3',
    'Kalimba',
    'Kami Retro',
    'Kentucky Route Zero: Act 1',
    'Kentucky Route Zero: Act 2',
    'Kentucky Route Zero: Act 4',
    'Kerbal Space Program',
    "Ketzal's Corridors",
    'Kick & Fennick',
    'KickBeat',
    'Kid Icarus Uprising',
    'Killer Instinct',
    'Killer is Dead',
    'Killzone 3',
    'Killzone: Mercenary',
    'Killzone: Shadow Fall',
    'Kinect Disneyland Adventures',
    'Kinect Party',
    'Kinect Rush: A Disney Pixar Adventure',
    'Kinect Sports Rivals',
    'Kinect Sports: Season 2',
    'Kinect: Star Wars',
    'King Arthur II: The Role-Playing Wargame',
    'King of Fighters XIV',
    "King's Quest -- Episode 1: A Knight to Remember",
    "King's Quest -- Episode 2: Rubble without a Cause",
    'Kingdom',
    'Kingdom Hearts 3D: Dream Drop Distance',
    'Kingdom Hearts HD 1.5 ReMIX',
    'Kingdom Hearts HD II.5 ReMIX',
    'Kingdom Hearts: Re:coded',
    'Kingdom Rush',
    'Kingdoms of Amalur: Reckoning',
    'Kingdoms of Amalur: Reckoning -- The Legend of Dead Kel',
    'Kirby and the Rainbow Curse',
    "Kirby's Dream Land",
    "Kirby's Return to Dream Land",
    'Kirby: Mass Attack',
    'Kirby: Planet Robobot',
    'Kirby: Triple Deluxe',
    'Knack',
    'Knights Contract',
    'Knights of Pen & Paper II',
    'Knock-Knock',
    "Kona's Crate",
    'Krater',
    'Kung Fu Dragon',
    'Kung Fu Panda 2',
    'Kyotokei',
    'L.A. Noire',
    'L.A. Noire The Complete Edition',
    'L.A. Noire: Reefer Madness',
    'LEGO Batman 2: DC Super Heroes',
    'LEGO Batman 3: Beyond Gotham',
    'LEGO City Undercover: The Chase Begins',
    'LEGO City: Undercover',
    'LEGO Dimensions',
    'LEGO Harry Potter: Years 5-7',
    'LEGO Jurassic World',
    'LEGO Marvel Super Heroes',
    "LEGO Marvel's Avengers",
    'LEGO Pirates of the Caribbean: The Video Game',
    'LEGO Star Wars III: The Clone Wars',
    'LEGO Star Wars: The Force Awakens',
    'LEGO Star Wars: The Yoda Chronicles',
    'LEGO The Lord of the Rings',
    'LEGO The Lord of the Rings [Portable]',
    'LEGO: The Hobbit',
    'Labyrinth Legends',
    'Land-a Panda',
    'Lara Croft Go',
    'Lara Croft and the Temple of Osiris',
    'Layers of Fear',
    'League of Evil',
    'League of Evil 2',
    'League of Legends',
    'Leedmees',
    'Left 4 Dead 2: Cold Stream',
    'Legasista',
    'Legend of Grimrock',
    'Legend of Grimrock II',
    'Legends of Aethereus',
    'Legends of Dawn',
    'Legends of Eisenwald',
    'Leisure Suit Larry Reloaded',
    "Let's Create! Pottery",
    "Let's Fish! Hooked On",
    "Let's Golf 3D",
    'Leviathan: Warships',
    'Lichdom: Battlemage',
    'Life is Strange -- Episode 1: Chrysalis',
    'Life is Strange -- Episode 2: Out of Time',
    'Life is Strange -- Episode 3: Chaos Theory',
    'Life is Strange -- Episode 4: Dark Room',
    'Lightning Returns: Final Fantasy XIII',
    'Lili: Child of Geos',
    'Limbo',
    'Liqua Pop',
    'Little Chomp',
    'Little Deviants',
    'Little Inferno',
    'LittleBigPlanet 2',
    'LittleBigPlanet 3',
    'LittleBigPlanet Karting',
    'LittleBigPlanet PS Vita',
    'LittleBigPlanet PS Vita -- Marvel Super Hero Edition',
    'Loadout',
    "Lock 'n' Chase",
    'LocoCycle',
    'Lollipop Chainsaw',
    'London 2012: The Official Video Game of the Olympic Games',
    'Lone Survivor',
    'Lone Survivor (Director’s Cut)',
    'Lords of the Fallen',
    'Lost Dimension',
    'Lost Planet 3',
    'Lost in Shadow',
    'Lovers in a Dangerous Spacetime',
    'Lucius',
    "Lucky's Tale",
    'Luftrausers',
    "Luigi's Mansion: Dark Moon",
    'Lumines: Electronic Symphony',
    'Luxor HD',
    'MANOS: The Hands of Fate',
    'MLB 11: The Show',
    'MLB 12: The Show',
    'MLB 13: The Show',
    'MLB 14: The Show',
    'MLB 15: The Show',
    'MLB Bobblehead Pros',
    'MLB The Show 16',
    'MX vs. ATV Alive',
    'Machinarium',
    'Mad Max',
    'Madden NFL 12',
    'Madden NFL 13',
    'Madden NFL 15',
    'Madden NFL 16',
    'Madden NFL 17',
    'Madden NFL 25',
    'Madden NFL Football',
    'Mage Gauntlet',
    'Magic 2015 -- Duels of the Planewalkers',
    'Magic: The Gathering -- Duels of the Planeswalkers 2012',
    'Magic: The Gathering -- Duels of the Planeswalkers 2013',
    'Magic: The Gathering -- Duels of the Planeswalkers 2014',
    'Magical Whip: Wizards of Phantasmal Forest',
    'Magicka',
    'Magicka 2',
    'Magicka: Wizard Wars',
    'Magnetic: Cage Closed',
    'Magrunner: Dark Pulse',
    'Major League Baseball 2K11',
    'Major League Baseball 2K12',
    'Major League Baseball 2K13',
    'Major Mayhem',
    'Make-Up & Style',
    'Malicious',
    'Man of Steel',
    'Man of Steel HD',
    'March of the Eagles',
    'Mario & Luigi: Dream Team',
    'Mario & Luigi: Paper Jam',
    'Mario & Sonic at the London 2012 Olympic Games',
    'Mario & Sonic at the Sochi 2014 Olympic Winter Games',
    'Mario Golf World Tour',
    'Mario Kart 7',
    'Mario Kart 8',
    'Mario Party 9',
    'Mario Party 10',
    'Mario Party: Island Tour',
    'Mario Sports Mix',
    'Mario Tennis Open',
    'Mario Tennis: Ultra Smash',
    'Mario and Donkey Kong: Minis on the Move',
    'Mario vs. Donkey Kong: Tipping Stars',
    "Mario's Picross",
    'Mark of the Ninja',
    'Mars: War Logs',
    "Maru's Mission",
    'Marvel Heroes',
    'Marvel Puzzle Quest: Dark Reign',
    'Marvel Vs. Capcom 3: Fate of Two Worlds',
    'Marvel vs. Capcom Origins',
    "Marvel's The Avengers: Battle For Earth",
    'Mass Effect',
    'Mass Effect 2',
    'Mass Effect 2: Arrival',
    'Mass Effect 3',
    'Mass Effect 3 (Special Edition)',
    'Mass Effect 3: Citadel',
    'Mass Effect 3: Leviathan',
    'Mass Effect Infiltrator',
    'Massive Chalice',
    'Master Reboot',
    'Master of Orion',
    'Max & the Magic Marker',
    'Max Payne',
    'Max Payne 3',
    'Max Payne 3 (Special Edition)',
    'Max: The Curse of Brotherhood',
    'MechWarrior Online',
    'Medal of Honor Warfighter',
    "Medieval Moves: Deadmund's Quest",
    'Mega Mall Story',
    'Mega Man 5',
    'Mega Man Legacy Collection',
    'Mega Man X',
    "Mega Man: Dr. Wily's Revenge",
    'Men Of War: Vietnam',
    'Mercenary Kings',
    'Mercury Hg',
    'Metal Gear Rising: Revengeance',
    'Metal Gear Solid 3D Snake Eater',
    'Metal Gear Solid HD Collection',
    'Metal Gear Solid V: Ground Zeroes',
    'Metal Gear Solid V: The Phantom Pain',
    'Metrico',
    'Metro: Last Light',
    'Metro: Redux',
    'Metroid II: Return of Samus',
    'Metroid Prime: Federation Force',
    'Miasmata',
    'Michael Jackson: The Experience',
    'Michael Jackson: The Experience HD',
    'MicroBot',
    'Micromon',
    'Microsoft Flight',
    'Middle-earth: Shadow of Mordor',
    'Middle-earth: Shadow of Mordor: The Bright Lord',
    'Midnight Star',
    'Midway Arcade Origins',
    'Might & Magic Heroes VI',
    'Might & Magic Heroes VII',
    'Might and Magic X Legacy',
    'Might and Magic: Clash of Heroes',
    'Mighty Gunvolt',
    'Mighty Milky Way',
    'Mighty No. 9',
    "Mighty No. 9 (Collector's Edition)",
    'Mighty Switch Force',
    'Mind Zero',
    'Mindjack',
    'Minecraft',
    'Minecraft -- Pocket Edition',
    'Minecraft: Story Mode -- Episode 1: The Order of the Stone',
    'Minecraft: Story Mode -- Episode 2: Assembly Required',
    'Minecraft: Story Mode -- Episode 3: The Last Place You Look',
    'Minecraft: Story Mode -- Episode 4: A Block and a Hard Place',
    'Miner Wars 2081',
    'Minigore 2: Zombies',
    'Minimum',
    'MinoMonsters',
    'Minute to Win It',
    "Mirror's Edge Catalyst",
    'Mittens',
    'ModNation Racers: Road Trip',
    'Modern Combat 3: Fallen Nation',
    'Modern Combat 4: Zero Hour',
    'Monaco',
    'Monochrome Racing',
    'Monster Hunter 3 Ultimate',
    'Monster Hunter 4 Ultimate',
    'Monster Hunter Generations',
    'Monster Monpiece',
    'Monster Tale',
    'Monsters Inc. Run',
    'Moon Diver',
    'Mortal Kombat',
    'Mortal Kombat Arcade Kollection',
    'Mortal Kombat X',
    'MotionSports Adrenaline',
    'Moto Extreme',
    'MotoHeroz',
    'Motocross Madness',
    'MotorStorm Apocalypse',
    'MotorStorm RC',
    'Mount & Blade: Warband',
    'Mount & Blade: With Fire & Sword',
    'MouseCraft',
    'MovieCat',
    'Mr. Crab',
    'Mr. Ninja',
    'Ms. Pac-Man',
    'Ms. Splosion Man',
    'Mugen Souls',
    'Muramasa Rebirth',
    'Murasaki Baby',
    'Murdered: Soul Suspect',
    'Mushroom 11',
    'Mutant Mudds',
    'Mutant Mudds Deluxe',
    'My Asian Farm',
    'My Australian Farm',
    'Mystery Case Files: The Malgrave Incident',
    'NASCAR The Game 2011',
    'NBA 2K12',
    'NBA 2K12: Legends Showcase',
    'NBA 2K13',
    'NBA 2K14',
    'NBA 2K15',
    'NBA 2K16',
    'NBA 2K17',
    'NBA Jam',
    'NBA Jam: On Fire Edition',
    'NBA Live 14',
    'NBA Live 15',
    'NBA Live 16',
    'NCAA Football 12',
    'NCAA Football 13',
    'NCAA Football 14',
    'NCIS: The Game',
    'NES Remix',
    'NES Remix 2',
    'NFL Blitz',
    'NHL 12',
    'NHL 13',
    'NHL 14',
    'NHL 15',
    'NHL 16',
    'NHL 17',
    'Nancy Drew: The Deadly Device',
    'Nano Assault Neo',
    'Narco Terror',
    'Naruto Shippuden: Kizuna Drive',
    'Naruto Shippuden: Ultimate Ninja Impact',
    'Naruto Shippuden: Ultimate Ninja Storm 3',
    'Naruto Shippuden: Ultimate Ninja Storm 4',
    'Naruto Shippuden: Ultimate Ninja Storm Generations',
    'Naruto: Powerful Shippuden',
    'Natural Doctrine',
    'Natural Selection 2',
    'Naughty Bear: Panic in Paradise',
    'Necropolis',
    'Need for Speed',
    'Need for Speed Most Wanted',
    'Need for Speed Most Wanted U',
    'Need for Speed Rivals',
    'Need for Speed: The Run',
    'Neo Scavenger',
    'NeverDead',
    'Neverwinter',
    'New Bust-A-Move',
    "New Little King's Story",
    'New Orbit',
    'New Super Luigi U',
    'New Super Luigi U (Nintendo eShop Edition)',
    'New Super Mario Bros. 2',
    'New Super Mario Bros. U',
    'Nexuiz',
    'Ni no Kuni: Wrath of the White Witch',
    "Nickelodeon's Teenage Mutant Ninja Turtles",
    'Nidhogg',
    'NightSky',
    'Ninja Fishing',
    'Ninja Gaiden III',
    "Ninja Gaiden III: Razor's Edge",
    'Ninja Gaiden Sigma 2 Plus',
    'Ninja Gaiden Sigma Plus',
    'Nintendo Land',
    'Nintendogs + Cats: French Bulldog & New Friends',
    'Nintendogs + Cats: Golden Retriever & New Friends',
    'Nintendogs + Cats: Toy Poodle & New Friends',
    "No Man's Sky",
    "No More Heroes: Heroes' Paradise",
    'Not the Robots',
    'Nuclear Throne',
    'NyxQuest: Kindred Spirits',
    'ORC: Vengeance',
    'Oblitus',
    'Octodad: Dadliest Catch',
    'Oculus Rift',
    "Oddworld: New 'n' Tasty",
    "Oddworld: Stranger's Wrath HD",
    'Odin Sphere Leifthrasir',
    'Off-Road Drive',
    'Offworld Trading Company',
    'Oh! Edo Towns',
    'Oil Rush',
    'Oio',
    'Okabu',
    'Okami HD',
    'Okamiden',
    'OlliOlli',
    'OlliOlli 2: Welcome to OlliWood',
    'Omerta: City of Gangsters',
    'One Man Army',
    'One Piece: Burning Blood',
    'One Piece: Pirate Warriors',
    'One Piece: Pirate Warriors 3',
    'One Piece: Romance Dawn',
    'One Piece: Unlimited World Red',
    'Operation Flashpoint: Red River',
    'Orbital Gear',
    'Orcs Must Die',
    'Orcs Must Die 2',
    'Orgarhythm',
    'Ori and The Blind Forest',
    'Orion: Dino Beatdown',
    "Oscar's World Tour",
    'Otomedius Excellent',
    'Out of the Park Baseball 15',
    'Outland',
    'Outlast',
    'Outlast: Whistleblower',
    'Overwatch',
    'OxenFree',
    'Pac-Man',
    'Pac-Man & Galaga Dimensions',
    'Pac-Man Championship Edition 2',
    'Pac-Man: Championship Edition',
    'Pacific Rim',
    'Page Chronica',
    'Painkiller: Hell & Damnation',
    'Paint Splash',
    "Pandora's Tower",
    'Papa Sangre',
    'Paper Mario: Sticker Star',
    'Paper Titans',
    'Paper Wars: Cannon Fodder',
    'Papers, Please',
    'Papo & Yo',
    'Patapon 3',
    'Path of Exile',
    'PayDay 2',
    'PayDay 2: Crimewave Edition',
    'PayDay: The Heist',
    'Peggle 2',
    "Penny Arcade's On the Rain-Slick Precipice of Darkness 3",
    "Penny Arcade's On the Rain-slick Precipice of Darkness 4",
    'Persona 2: Innocent Sin',
    'Persona 4 Arena',
    'Persona 4 Arena Ultimax',
    'Persona 4 Golden',
    'Persona 4: Dancing All Night',
    'Persona Q: Shadow of the Labyrinth',
    'Phantom Breaker: Battle Grounds',
    'Phoenix Wright: Ace Attorney -- Dual Destinies',
    'Phoenix Wright: Ace Attorney -- Spirit of Justice',
    'Pickpawcket',
    'Pid',
    'Pikmin 3',
    'Pillar of Eternity: The White March - Part II',
    'Pillars of Eternity',
    'PilotWings Resort',
    'Pineapple Smash Crew',
    "Pinocchio's Puzzle",
    'Pirates of Black Cove',
    'Pitfall',
    'Pixel People',
    'Pixel Racer',
    'PixelJunk Monsters: Ultimate HD',
    'PixelJunk Shooter 2',
    'PixelJunk: SideScroller',
    'Plague Inc.',
    'PlanetSide 2',
    'Planetary Annihilation',
    'Plants vs. Zombies',
    'Plants vs. Zombies 2',
    'Plants vs. Zombies: Garden Warfare',
    'Plants vs. Zombies: Garden Warfare 2',
    'Play & Learn Chinese',
    'Play & Learn Spanish',
    'PlayStation All-Stars Battle Royale',
    'PlayStation Move Heroes',
    'Playstation Move: Ape Escape',
    'Pocket Clothier',
    'Pocket League Story',
    'Pokemon Alpha Sapphire Version',
    'Pokemon Battle Trozei',
    'Pokemon Black Version',
    'Pokemon Black Version 2',
    'Pokemon Conquest',
    'Pokemon Go',
    'Pokemon Omega Ruby Version',
    'Pokemon Rumble Blast',
    'Pokemon Trading Card Game Online',
    'Pokemon White Version',
    'Pokemon White Version 2',
    'Pokemon X',
    'Pokemon Y',
    'Pokken Tournament',
    'PokéPark 2: Wonders Beyond',
    'Pollen Count',
    'Pony Island',
    'Portal 2',
    'Postal III',
    'PowerUp Heroes',
    'Powerstar Golf',
    'Primal Carnage',
    'Prime World',
    'Primordia',
    'Prince of Persia Classic Trilogy HD',
    'Prinny 2: Dawn of Operation Panties, Dood!',
    'Prison Architect',
    'Pro Evolution Soccer 2011',
    'Pro Evolution Soccer 2012',
    'Pro Evolution Soccer 2013',
    'Pro Evolution Soccer 2014',
    'Pro Evolution Soccer 2015',
    'Pro Evolution Soccer 2016',
    'Pro Evolution Soccer 2017',
    'Pro Jumper! Guilty Gear Tangent',
    'Professor Layton and the Azran Legacy',
    'Professor Layton and the Last Specter',
    'Professor Layton and the Miracle Mask',
    'Professor Layton vs. Phoenix Wright',
    'Project CARS',
    'Project Highrise',
    'Project Spark',
    'Project X Zone',
    'Project X Zone 2',
    'Proteus',
    'Prototype 2',
    'Proun',
    "Pucca's Kisses Game",
    'Pudding Monsters',
    'Puddle',
    'Pulse: Volume One',
    'Punch Club',
    'Punch Quest',
    'Puppeteer',
    'Pure Chess',
    'Pushmo',
    'Puzzle & Dragons Z + Puzzle & Dragons Super Mario Bros. Edition',
    'Puzzle Craft',
    'Puzzle Dimension',
    'Puzzle Fever',
    'Puzzle Rocks',
    'Pyramids',
    'QUBE',
    'Quadrilateral Cowboy',
    'Quantum Break',
    'Quantum Conundrum',
    'Quarrel',
    'Quest Runner',
    'Quick Fill Q',
    'Quiz Climber',
    'R.I.P.D.: The Game',
    'RBI Baseball 14',
    'RBI Baseball 15',
    'Rabbids Land',
    'Radar Mission',
    'Radiant Historia',
    'Radiant Silvergun',
    'Rage',
    'Rage of the Gladiator',
    'Ragnarok Odyssey',
    'Railroad Story',
    'Rain',
    'Rainbow Moon',
    'Rainbow Six: Shadow Vanguard',
    'Rambo: The Video Game',
    'Ramps',
    "Randal's Monday",
    'Rare Replay',
    'Ratchet & Clank',
    'Ratchet & Clank Collection',
    'Ratchet & Clank: All 4 One',
    'Ratchet & Clank: Full Frontal Assault',
    'Ratchet & Clank: Into the Nexus',
    'Ravaged',
    "Raven's Cry",
    'Ravensword: Shadowlands',
    'Raving Rabbids: Alive & Kicking',
    'Raving Rabbids: Travel in Time 3D',
    'Rayman 3: Hoodlum Havoc HD',
    'Rayman 3D',
    'Rayman Fiesta Run',
    'Rayman Legends',
    'Rayman Origins',
    'Rayman: Jungle Run',
    'ReCore',
    'Real Boxing',
    'Real Racing 2 HD',
    'Real Racing 3',
    'Real Steel',
    'Realm of the Mad God',
    'Realms Of Ancient War',
    'Rebel Galaxy',
    'Record of Agarest War Zero',
    'Red Faction: Armageddon',
    'Red Faction: Battlegrounds',
    'Red Orchestra 2: Heroes of Stalingrad',
    'Red Orchestra 2: Rising Storm',
    'Redshirt',
    'Regular Show: Mordecai and Rigby in 8-Bit Land',
    'Rekoil',
    'Relic Rush',
    'Remember Me',
    'Remote Racers',
    'Renegade Ops',
    'Republique -- Episode 1: Exordium',
    'Republique -- Episode 2: Metamorphosis',
    'Resident Evil',
    'Resident Evil 4 HD',
    'Resident Evil 6',
    'Resident Evil -- CODE: Veronica X HD',
    'Resident Evil Mercenaries VS',
    'Resident Evil Revelations',
    'Resident Evil Revelations 2',
    'Resident Evil Revelations 2 -- Episode 1',
    'Resident Evil Revelations 2 -- Episode 2',
    'Resident Evil Revelations 2 -- Episode 3',
    'Resident Evil Revelations 2 -- Episode 4',
    'Resident Evil Zero',
    'Resident Evil: Operation Raccoon City',
    'Resident Evil: The Mercenaries 3D',
    'Resistance 3',
    'Resistance: Burning Skies',
    'Resogun',
    'Resogun Heroes',
    'Resonance',
    'Retro City Rampage',
    'Retro/Grade',
    'Retrovirus',
    'Reus',
    'Revenge of The Titans',
    'Rhythm Heaven Fever',
    'Rhythm Party',
    'Rick and Morty: Pocket Mortys',
    'Ricochet HD',
    'Ridge Racer',
    'Ridge Racer 3D',
    'Ridge Racer Accelerated HD',
    'Ridiculous Fishing: A Tale of Redemption',
    'Rift',
    'Rift: Storm Legion',
    'Rise of Immortals',
    'Rise of Incarnates',
    'Rise of Nightmares',
    'Rise of the Tomb Raider',
    'Rise of the Tomb Raider -- Baba Yaga: The Temple of the Witch',
    'Rise of the Tomb Raider -- Cold Darkness Awakened',
    'Rise of the Triad',
    'Risen 2: Dark Waters',
    'Risen 3: Titan Lords',
    'Risk: Factions',
    'Rival Turf',
    'Rive',
    'Road Blaster',
    'Road Not Taken',
    'RoboSockets',
    'Robot Unicorn Attack 2',
    'Roboto',
    'Rochard',
    'Rock Band 4',
    'Rock Band Blitz',
    'Rock of Ages',
    'Rocket League',
    'Rocketbirds: Hardboiled Chicken',
    'Rocksmith',
    'Rocksmith 2014',
    'Rogue Legacy',
    'Roller Coaster Rampage',
    'Rory McIlroy PGA Tour',
    'Rugby 15',
    'Rugby Challenge',
    'Rugby League Live 2',
    'Rugby League Live 3',
    'Rugby World Cup 2011',
    'Rugby World Cup 2015',
    'Run Roo Run',
    'Rune Factory 4',
    'Rune Factory: Tides of Destiny',
    'Runespell: Overture',
    "Rush'N Attack Ex-Patriot",
    'Ryse: Son of Rome',
    'Rytmik Retrobits',
    'S.C.A.T.: Special Cybernetic Attack Team',
    'SBK 2011',
    'SOCOM 4: U.S. Navy SEALs',
    'SOL: Exodus',
    'SSX',
    'Sacred 3',
    'Sacred Citadel',
    'Sacred Odyssey: Rise of Ayden',
    'Saint Seiya: Brave Soldiers',
    'Saints Row IV',
    'Saints Row IV: Gat Out of Hell',
    'Saints Row IV: Re-Elected & Gat Out of Hell',
    'Saints Row: The Third',
    'Sakura Samurai: Art of the Sword',
    'Salt and Sanctuary',
    'Sam & Max: Beyond Time and Space',
    'Samurai Bloodshow',
    'Samurai Gunn',
    'Samurai Sword Destiny',
    'Samurai Warriors Chronicles',
    'Sanctum 2',
    'ScaryGirl',
    'Scene It? Movie Night',
    'Screamride',
    'Screencheat',
    'Scribblenauts Remix',
    'Scribblenauts Unlimited',
    'Scribblenauts Unmasked: A DC Comics Adventure',
    'Scrolls',
    'Secret Ponchos',
    'Section 8: Prejudice',
    'Self-Defense Training Camp',
    'Serious Sam 3: BFE',
    'Serious Sam: Double D',
    'Serious Sam: The Random Encounter',
    'Sesame Street: Once Upon a Monster',
    'Severed',
    "Shad'O",
    'Shadow Harvest: Phantom Ops',
    'Shadow Warrior',
    'Shadowgate -- The Classic Adventure Re-Imagined',
    'Shadowgun',
    'Shadowrun Chronicles: Boston Lockdown',
    'Shadowrun Returns',
    'Shadowrun: Hong Kong',
    'Shadows of the Damned',
    'Shank 2',
    "Shantae and the Pirate's Curse",
    'Sharknado: The Video Game',
    'Sherlock Holmes: Crimes & Punishments',
    'Shift 2 Unleashed',
    'Shin Megami Tensei IV',
    'Shin Megami Tensei: Devil Survivor Overclocked',
    'Shinobi',
    'Shinobi III: Return of the Ninja Master',
    'Shinobido 2: Revenge of Zen',
    'Shoot Many Robots',
    'ShootMania Storm',
    'Shovel Knight',
    "Sid Meier's Civilization Revolution 2",
    "Sid Meier's Civilization V: Brave New World",
    "Sid Meier's Civilization V: Gods & Kings",
    "Sid Meier's Civilization: Beyond Earth",
    "Sid Meier's Civilization: Beyond Earth -- Rising Tide",
    "Sid Meier's Pirates!",
    "Sid Meier's Starships",
    'Side Pocket',
    'Sideway: New York',
    'Siege Hero',
    'Siesta Fiesta',
    'Silent Hill HD Collection',
    'Silent Hill: Book of Memories',
    'Silent Hill: Downpour',
    'SimCity',
    'SimCity: Cities of Tomorrow',
    'Simply Minesweeper',
    'Sine Mora',
    'Sing Party',
    'Sins of a Solar Empire: Rebellion',
    'Sir, You are Being Hunted',
    'Ski Safari',
    'Skullgirls',
    'Skulls of the Shogun',
    'Sky Gamblers: Storm Raiders',
    'Skydrift',
    'Skylanders Battlegrounds',
    'Skylanders Giants',
    "Skylanders Spyro's Adventure",
    'Skylanders SuperChargers',
    'Skylanders Swap Force',
    'Skylanders Trap Team',
    'Slam Bolt Scrappers',
    'Sleeping Dogs',
    'Sleeping Dogs: Definitive Edition',
    'Slender: The Arrival',
    'Slingo Supreme',
    'Sly Cooper: Thieves in Time',
    'Smart As...',
    'Smite',
    'Snapshot',
    'Sniper Elite III',
    'Sniper Elite V2',
    'Sniper: Ghost Warrior',
    'Sniper: Ghost Warrior 2',
    'Soccer Up',
    'Solar 2',
    'Solatorobo: Red The Hunter',
    'Soma',
    'SonSon (Arcade)',
    'Song of the Deep',
    'Sonic & All-Stars Racing Transformed',
    'Sonic Boom: Rise of Lyric',
    'Sonic Boom: Shattered Crystal',
    'Sonic CD',
    'Sonic Dash',
    'Sonic Generations',
    'Sonic Jump',
    'Sonic the Hedgehog 4: Episode II',
    'Sonic: Lost World',
    'Soul Sacrifice',
    'Soulcalibur V',
    'Sound Shapes',
    'Soundodger',
    'Sour Patch Kids: World Gone Sour',
    "South Park: Tenorman's Revenge",
    'South Park: The Stick of Truth',
    'Space Hulk',
    'Spacebase DF-9',
    'Spare Parts',
    'Spec Ops: The Line',
    'Special Forces: Team X',
    'Speedball 2 Evolution',
    'Spelunky',
    'Spider-Man: Edge of Time',
    'Spirit Camera: The Cursed Memoir',
    'Splatoon',
    'Splice: Tree of Life',
    "SpongeBob SquarePants: Plankton's Robotic Revenge",
    'SpongeBob SquigglePants',
    'Sports Champions 2',
    'Sportsfriends',
    'Sprinkle',
    'Spy Mouse',
    'Stacking',
    'Star Command',
    'Star Fox 64 3D',
    'Star Fox Guard',
    'Star Fox Zero',
    'Star Ocean: Integrity and Faithlessness',
    'Star Trek: The Game',
    'Star Wars Battlefront',
    'Star Wars Knights of the Old Republic',
    'Star Wars: The Old Republic',
    'Star Wars: The Old Republic -- Knights of the Fallen Empire',
    'Star Wars: The Old Republic -- Rise of the Hutt Cartel',
    'Star Wars: Uprising',
    'StarCraft II: Heart of the Swarm',
    'StarCraft II: Legacy of the Void',
    'StarDrive',
    'StarDrive 2',
    'StarDrone Extreme',
    'StarFront: Collision',
    'Starbound',
    'Starcraft II: Nova Covert Ops -- Mission Pack 1',
    'Starcraft II: Nova Covert Ops -- Mission Pack 2',
    'Stardew Valley',
    'Starhawk',
    'Starlight Inception',
    'State of Decay',
    'State of Decay: Year One Survival Edition',
    'Stealth Inc. 2: A Game of Clones',
    'Stealth Inc.: A Clone in the Dark',
    'SteamWorld Dig',
    'SteamWorld Heist',
    'Steel Battalion: Heavy Armor',
    'Steel Diver',
    'Steel Diver: Sub Wars',
    'Steins;Gate',
    'Stellaris',
    'Step Up',
    'Stick it to The Man',
    'Stickman BMX',
    'Storm',
    'Storm in a Teacup',
    'Story of Seasons',
    'Strange Rain',
    'Stratego: Next Edition',
    'Street Fighter III: Third Strike -- Online Edition',
    'Street Fighter V',
    'Street Fighter X Mega Man',
    'Street Fighter x Tekken',
    'StreetPass Flower Town',
    'StreetPass Mii Force',
    'StreetPass Monster Manor',
    "StreetPass Warrior's Way",
    'Streets of Rage 2',
    'Strider',
    'Strike Suit Zero',
    'Stronghold 3',
    'Styx: Master of Shadows',
    'Submerged',
    'Sumioni: Demon Arts',
    'SunFlowers',
    'Sunless Sea',
    'Sunset',
    'Sunset Overdrive',
    'Sunset Overdrive -- Mystery of the Mooil Rig',
    'Super Adventure Island 2',
    'Super Bonk',
    'Super Comboman',
    'Super Crate Box',
    'Super Hexagon',
    'Super House of Dead Ninjas',
    'Super Mario 3D Land',
    'Super Mario 3D World',
    'Super Mario Land',
    'Super Mario Land 2',
    'Super Mario Maker',
    'Super Mega Baseball',
    'Super Monday Night Combat',
    'Super Monkey Ball 3D',
    'Super Motherload',
    'Super Smash Bros. for Nintendo 3DS',
    'Super Smash Bros. for Wii U',
    'Super Stardust Delta',
    'Super Stickman Golf 2',
    'Super Street Fighter IV 3D Edition',
    'Super Street Fighter IV: Arcade Edition',
    'Super TIME Force',
    'Superbrothers: Sword & Sworcery EP',
    'Superhot',
    'Supremacy MMA',
    'Supreme League of Patriots',
    'Surge Deluxe',
    'Surgeon Simulator 2013',
    'Survivor',
    'Swarm',
    'Swing the Bat',
    'Sword & Sworcery EP',
    'Sword Art Online: Hollow Fragment',
    'Sword Art Online: Lost Song',
    'Sword Coast Legends',
    'Sword of the Stars II: Lords of Winter',
    'Swords & Soldiers',
    'Symphonica: Grand Maestro',
    'Symphony',
    'Syndicate',
    'Taco Master',
    'Tactics Ogre: Let Us Cling Together',
    'Takedown: Red Sabre',
    'Tales from Space: About a Blob',
    'Tales from Space: Mutant Blobs Attack',
    'Tales from the Borderlands -- Episode 1: Zer0 Sum',
    'Tales from the Borderlands -- Episode 2: Atlas Mugged',
    'Tales from the Borderlands -- Episode 3:  Catch a Ride',
    'Tales from the Borderlands -- Episode 4: Escape Plan Bravo',
    'Tales from the Borderlands -- Episode 5 The Vault of the Traveler',
    'Tales of Symphonia Chronicles',
    'Tales of Xillia',
    'Tales of Xillia 2',
    'Tales of Zestiria',
    'Tales of the Abyss',
    'Tank! Tank! Tank!',
    'Tapper World Tour',
    'Tearaway',
    'Tearaway Unfolded',
    'Tecmo Bowl Throwback [Mobile]',
    'Teenage Mutant Ninja Turtles: Danger of the Ooze',
    'Teenage Mutant Ninja Turtles: Mutants in Manhattan',
    'Teenage Mutant Ninja Turtles: Out of the Shadows',
    'Teenage Mutant Ninja Turtles: Rooftop Run',
    'Tekken 3D: Prime Edition',
    'Tekken Hybrid',
    'Tekken Tag Tournament 2',
    'Tekken Tag Tournament 2: Wii U Edition',
    'Teleglitch: Die More Edition',
    "Telltale Games' Poker Night 2",
    'Tembo the Badass Elephant',
    'Temple Run',
    'Tennis',
    'Tera: Rising',
    'Terraria',
    'Tesla Effect: A Tex Murphy Adventure',
    'Test Drive Unlimited 2',
    'Test Drive: Ferrari Racing Legends',
    'Tetris',
    'Tetris (EA)',
    'Tetris: Axis',
    'Tharsis',
    'That Dragon, Cancer',
    'The 3rd Birthday',
    'The Adventures of Tintin',
    'The Amazing Spider-Man',
    'The Amazing Spider-Man 2',
    'The Baconing',
    'The Banner Saga',
    'The Banner Saga 2',
    'The Banner Saga: Factions',
    "The Beginner's Guide",
    'The Binding of Isaac',
    'The Binding of Isaac: Rebirth',
    'The Black Eyed Peas Experience',
    'The Bureau: XCOM Declassified',
    'The Castle Doctrine',
    'The Cave',
    'The Crew',
    'The Cursed Crusade',
    'The Dark Knight Rises',
    'The Dark Meadow',
    'The Darkness II',
    'The Denpa Men 2: Beyond the Waves',
    'The Dishwasher: Vampire Smile',
    'The Earth Defense Force 2017 Portable',
    'The Earth Defense Force: Insect Armageddon',
    'The Elder Scrolls Online',
    'The Elder Scrolls V: Skyrim',
    'The Elder Scrolls V: Skyrim -- Dawnguard',
    'The Elder Scrolls V: Skyrim -- Dragonborn',
    'The Escapists',
    'The Evil Within',
    'The Evil Within: The Assignment',
    'The Evil Within: The Consequence',
    'The Evil Within: The Executioner',
    'The Expendables 2 Videogame',
    'The Fancy Pants Adventures',
    'The First Templar',
    'The Flame in the Flood',
    'The Golf Club',
    "The Golf Club: Collector's Edition",
    'The Guided Fate Paradox',
    'The Gunstringer',
    'The Haunted: Hells Reach',
    'The House of the Dead III',
    'The House of the Dead: Overkill -- Extended Cut',
    'The House of the Dead: Overkill -- The Lost Reels',
    'The Ico & Shadow of the Colossus Collection',
    'The Ignition Factor',
    'The Incredible Adventures of Van Helsing',
    'The Incredible Adventures of Van Helsing II',
    'The King of Fighters XIII',
    'The Kore Gang',
    'The LEGO Movie Videogame',
    'The Last Federation',
    'The Last Rocket',
    'The Last Story',
    'The Last of Us',
    'The Last of Us: Left Behind',
    'The Last of Us: Remastered',
    'The Legend of Heroes: Trails in the Sky',
    'The Legend of Korra',
    'The Legend of Zelda: A Link Between Worlds',
    'The Legend of Zelda: Four Swords Anniversary Edition',
    "The Legend of Zelda: Link's Awakening DX",
    "The Legend of Zelda: Majora's Mask 3D",
    'The Legend of Zelda: Ocarina of Time 3D',
    'The Legend of Zelda: Skyward Sword',
    'The Legend of Zelda: The Wind Waker HD',
    'The Legend of Zelda: The Wind Waker HD (Nintendo eShop Edition)',
    'The Legend of Zelda: Tri Force Heroes',
    'The Legend of Zelda: Twilight Princess HD',
    'The Lord of the Rings Online: Riders of Rohan',
    'The Lord of the Rings: War in the North',
    'The Lost Town: The Dust',
    'The Magic Circle',
    'The Mooniacs',
    'The Mystery of Whiterock Castle',
    'The Night of the Rabbit',
    'The Novelist',
    'The Order: 1886',
    'The Other Brothers',
    'The Park',
    'The Pinball Arcade',
    'The Political Machine 2012',
    'The Raven: Legacy of a Master Thief Chapter I: The Eye of the Sphinx',
    'The Raven: Legacy of a Master Thief Chapter II: Ancestry of Lies',
    'The Raven: Legacy of a Master Thief Chapter III: A Murder of Ravens',
    'The Room Three',
    'The Room Two',
    'The Secret World',
    'The Showdown Effect',
    'The Simpsons: The Arcade Game',
    'The Sims 3',
    'The Sims 3: Generations',
    'The Sims 3: Pets',
    'The Sims 3: Seasons',
    'The Sims 3: Supernatural',
    'The Sims 4',
    'The Sims Medieval',
    'The Sims Medieval: Pirates and Nobles',
    'The Sly Collection',
    'The Splatters',
    'The Stanley Parable',
    'The Starship Damrey',
    'The Sushi Spinnery',
    'The Swapper',
    'The Talos Principle',
    'The Technomancer',
    'The Turing Test',
    'The Unfinished Swan',
    'The Vanishing of Ethan Carter',
    'The Walking Dead -- Game of the Year Edition',
    'The Walking Dead: 400 Days',
    'The Walking Dead: A Telltale Game Series -- Season One',
    'The Walking Dead: A Telltale Game Series -- Season Two',
    'The Walking Dead: Assault',
    'The Walking Dead: Michonne -- Episode 1: In Too Deep',
    'The Walking Dead: Michonne -- Episode 2: Give No Shelter',
    'The Walking Dead: Michonne -- Episode 3: What We Deserve',
    'The Walking Dead: Season Two -- Episode 1: All That Remains',
    'The Walking Dead: Season Two -- Episode 2: A House Divided',
    "The Walking Dead: Season Two -- Episode 3: In Harm's Way",
    'The Walking Dead: Season Two -- Episode 4: Amid the Ruins',
    'The Walking Dead: Season Two -- Episode 5: No Going Back',
    'The Walking Dead: Survival Instinct',
    'The Walking Dead: The Game -- Episode 2: Starved For Help',
    'The Walking Dead: The Game -- Episode 3: Long Road Ahead',
    'The Walking Dead: The Game -- Episode 4: Around Every Corner',
    'The Walking Dead: The Game -- Episode 5: No Time Left',
    'The War of the Worlds',
    'The Witch and the Hundred Knight',
    'The Witcher 2: Assassins of Kings',
    'The Witcher 2: Assassins of Kings (Enhanced Edition)',
    'The Witcher 3: Wild Hunt',
    'The Witcher 3: Wild Hunt -- Blood and Wine',
    'The Witcher 3: Wild Hunt -- Hearts of Stone',
    'The Witcher Adventure Game',
    'The Witcher Battle Arena',
    'The Witness',
    'The Wolf Among Us: Episode 1 -- Faith',
    'The Wolf Among Us: Episode 2 -- Smoke and Mirrors',
    'The Wolf Among Us: Episode 3 -- A Crooked Mile',
    "The Wolf Among Us: Episode 4 -- In Sheep's Clothing",
    'The Wolf Among Us: Episode 5 -- Cry Wolf',
    'The Wonderful 101',
    'The World Ends with You: Solo Remix',
    'Theatre of War 3: Korea',
    'Theatrhythm Final Fantasy',
    'Theatrhythm Final Fantasy: Curtain Call',
    'They Bleed Pixels',
    'Thief',
    'Thirty Flights of Loving',
    'This War Of Mine',
    'Thomas Was Alone',
    'Thor: God of Thunder',
    'Threes',
    'Thunder Wolves',
    'Ticket to Ride',
    'Tiger Woods PGA Tour 12: The Masters',
    'Tiger Woods PGA Tour 13',
    'Tiger Woods PGA Tour 14',
    'Time and Eternity',
    "Tiny & Big: Grandpa's Leftovers",
    'Tiny Brains',
    'Tiny Wings',
    'Titan Attacks!',
    'Titan Souls',
    'Titanfall',
    "Titanfall (Collector's Edition)",
    'To the Moon',
    "Tobe's Vertical Adventure",
    'Toki Tori 2',
    'Tokyo Crash Mobs',
    'Tokyo Jungle',
    'Tokyo Mirage Sessions #FE',
    "Tom Clancy's Ghost Recon Phantoms",
    "Tom Clancy's Ghost Recon: Future Soldier",
    "Tom Clancy's Ghost Recon: Future Soldier (Signature Edition)",
    "Tom Clancy's Ghost Recon: Shadow Wars",
    "Tom Clancy's Rainbow Six Siege",
    "Tom Clancy's Splinter Cell 3D",
    "Tom Clancy's Splinter Cell Classic Trilogy HD",
    "Tom Clancy's Splinter Cell: Blacklist",
    "Tom Clancy's The Division",
    "Tom Clancy's The Division -- Underground",
    'Tomb Breaker',
    'Tomb Raider',
    'Tomb Raider Trilogy',
    'Tomb Raider: Definitive Edition',
    'Tomodachi Life',
    "Tony Hawk's Pro Skater 5",
    "Tony Hawk's Pro Skater HD",
    'Top Spin 4',
    'Torchlight',
    'Torchlight II',
    'Total War Battles: Shogun',
    'Total War: Attila',
    'Total War: Rome II',
    'Total War: Shogun 2',
    'Total War: Shogun 2 -- Fall of The Samurai',
    'Total War: Warhammer',
    'Touch My Katamari',
    'Toukiden: The Age of Demons',
    'TowerFall Ascension',
    'Toy Soldiers: Cold War',
    'TrackMania Turbo',
    'TrackMania: Build to Race',
    'Trackmania 2: Canyon',
    'Transformers Prime',
    'Transformers: Dark of the Moon',
    'Transformers: Dark of the Moon -- Autobots',
    'Transformers: Dark of the Moon -- Decepticons',
    'Transformers: Dark of the Moon -- Stealth Force Edition',
    'Transformers: Devastation',
    'Transformers: Fall of Cybertron',
    'Transformers: Rise of the Dark Spark',
    'Transistor',
    'Trapped Dead',
    'Trauma',
    'Trenches Generals',
    'Trials Evolution',
    'Trials Fusion',
    'Trials of the Blood Dragon',
    'Tribes: Ascend',
    'Trine 2',
    "Trine 2: Director's Cut",
    "Trinity: Souls of Zill O'll",
    'Triple Town',
    'Trollboarder',
    'Tropico 4',
    'Tropico 5',
    'True Skate',
    'Twisted Metal',
    'Two Worlds II',
    'Two Worlds II: Castle Defense',
    'TxK',
    'UEFA Euro 2012',
    'UFC Personal Trainer: The Ultimate Fitness System',
    'UFC Undisputed 3',
    'Ultimate Marvel Vs. Capcom 3',
    'Ultra Street Fighter IV',
    'Umbrella Corps',
    'Unchained Blades',
    "Uncharted 3: Drake's Deception",
    "Uncharted 4: A Thief's End",
    'Uncharted: Fight For Fortune',
    'Uncharted: Golden Abyss',
    'Uncharted: The Nathan Drake Collection',
    'Under Siege',
    'Undertale',
    'Unepic',
    'Unit 13',
    'Unravel',
    'Unstoppable Gorg',
    'Until Dawn',
    'VVVVVV',
    'Valiant Hearts: The Great War',
    'Valkyria Chronicles',
    'Valkyria Chronicles Remastered',
    'Valley',
    'Velocispider',
    'Velocity',
    'Velocity 2X',
    'Velocity Ultra',
    'Venetica',
    'Venture Towns',
    'Vessel',
    'Virginia',
    'Virtua Fighter 2',
    'Virtua Fighter 5 Final Showdown',
    'Virtua Tennis 4',
    'Virtua Tennis 4: World Tour Edition',
    'Volcano Escape',
    'Voltron: Defender of the Universe',
    'Volume',
    'WRC 2 FIA World Rally Championship',
    'WRC 3 FIA World Rally Championship',
    'WWE 2K14',
    'WWE 2K15',
    'WWE 2K16',
    "WWE '12",
    "WWE '13",
    'WWE All Stars',
    'Waking Mars',
    'War Pinball',
    'War Thunder',
    'War of the Roses',
    'War of the Vikings',
    'Warframe',
    'Wargame: AirLand Battle',
    'Wargame: European Escalation',
    'Wargame: Red Dragon',
    'Warhammer 40,000: Dawn of War II -- Retribution',
    'Warhammer 40,000: Kill Team',
    'Warhammer 40,000: Space Marine',
    'Warhammer Quest',
    'Warhammer: End Times -- Vermintide',
    'Warlock: Master of the Arcane',
    'Warp',
    'Warriors Orochi 3',
    'Warriors Orochi 3 Hyper',
    'Warriors: Legends of Troy',
    'Wasteland 2',
    "Wasteland 2: Director's Cut",
    'Wasteland Angel',
    'Watch Dogs',
    'Watch Dogs: Bad Blood',
    'Waves',
    'Way of the Samurai 4',
    'When Vikings Attack',
    'Where is my Heart?',
    "Where's My Water?",
    'Whispering Willows',
    'White Night',
    "Who's That Flying!?",
    'Wii Fit U',
    'Wii Party U',
    'Wii Play: Motion',
    'Wii Sports Club',
    'Wii Sports Club (Retail Edition)',
    'Wild Blood',
    'WildStar',
    'Wipeout In the Zone',
    'Wizardry: The Labyrinth of Lost Souls',
    'Wolfenstein: The New Order',
    'Wolfenstein: The Old Blood',
    'Wonderbook: Book  of Spells',
    'Word Searcher 4',
    'WordJong Arcade',
    'World Cruise Story',
    'World War Z',
    'World of Goo',
    'World of Tanks',
    'World of Warcraft: Legion',
    'World of Warcraft: Mists of Pandaria',
    'World of Warcraft: Warlords of Draenor',
    'World of Warplanes',
    'World of Warships',
    'Worms Crazy Golf',
    'Worms Revolution',
    'Worms WMD',
    'Wraithborne',
    'Wreckateer',
    'Writer Rumble',
    'X Rebirth',
    'X-Men: Battle of the Atom',
    'X-Men: Destiny',
    'XCOM 2',
    'XCOM 2: Alien Hunters',
    "XCOM 2: Shen's Last Gift",
    'XCOM: Enemy Unknown',
    'XCOM: Enemy Within',
    'XCOM: Enemy Within -- Commander Edition',
    'Xenoblade Chronicles',
    'Xenoblade Chronicles X',
    'Xenonauts',
    'Xeodrifter',
    'Xmas Puzzle',
    'Xotic',
    'Yaiba: Ninja Gaiden Z',
    'Yakuza 4',
    'Yakuza: Dead Souls',
    "Yar's Revenge",
    'Year Walk',
    'Yo-Kai Watch',
    'YooStar 2',
    "Yoshi's New Island",
    "Yoshi's Woolly World",
    "You Don't Know Jack",
    "You Don't Know Jack (2011)",
    'Young Justice: Legacy',
    'Your Doodles Are Bugged',
    'Your Shape: Fitness Evolved 2012',
    'Ys I & II Chronicles',
    'Ys: Memories of Celceta',
    "Yu-Gi-Oh! 5D's World Championship 2011: Over The Nexus",
    'Zack Zero',
    'Zeit 2',
    'Zen Pinball 3D',
    'Zeno Clash II',
    'Zenonia 3: The Midgard Story',
    "Zero Escape: Virtue's Last Reward",
    'Zero Time Dilemma',
    'Zombi',
    'ZombiU',
    'Zombie Apocalypse: Never Die Alone',
    'Zombie Gunship',
    'Zombie Parkour Runner',
    "Zombie Tycoon 2: Brainhov's Revenge",
    'Zone of the Enders HD Collection',
    'Zoo Tycoon',
    'Zoombies: Animales de la Muerte',
    'Zoonies: Escape from Makatu',
    "Zuma's Revenge",
    'Zumba Fitness World Party',
    'de Blob 2',
    'iBlast Moki 2',
    'iStunt 2',
]
