"""Provides all the data related to the development."""

CONTAINER = [
    'Docker',
    'Rkt',
    'LXC',
    'Vagrant',
    'OpenVZ',
    'Kubernetes',
]

VERSION_CONTROL_SYSTEMS = [
    'Git',
    'Mercurial',
    'Subversion',
]

LICENSES = [
    'Apache License, 2.0 (Apache-2.0)',
    'The BSD 3-Clause License',
    'The BSD 2-Clause License',
    'GNU General Public License (GPL)',
    'General Public License (LGPL)',
    'MIT License (MIT)',
    'Mozilla Public License 2.0 (MPL-2.0)',
    'Common Development and Distribution License (CDDL-1.0)',
    'Eclipse Public License (EPL-1.0)',
]

PROGRAMMING_LANGS = [
    'ASP',
    'Assembly',
    'AutoIt',
    'Awk',
    'Bash',
    'C',
    'C Shell',
    'C#',
    'C++',
    'Caml',
    'Ceylon',
    'Clojure',
    'CoffeeScript',
    'Common Lisp',
    'D',
    'Dart',
    'Delphi',
    'Dylan',
    'ECMAScript',
    'Elixir',
    'Emacs Lisp',
    'Erlang',
    'F#',
    'Falcon',
    'Fortran',
    'GNU Octave',
    'Go',
    'Groovy',
    'Haskell',
    'haXe',
    'Io',
    'J#',
    'Java',
    'JavaScript',
    'Julia',
    'Kotlin',
    'Lisp',
    'Lua',
    'Mathematica',
    'Objective-C',
    'OCaml',
    'Perl',
    'PHP',
    'PL-I',
    'PL-SQL',
    'PowerShell',
    'Prolog',
    'Python',
    'R',
    'Racket',
    'Ruby',
    'Rust',
    'Scala',
    'Scheme',
    'Smalltalk',
    'Tcl',
    'Tex',
    'Transact-SQL',
    'TypeScript',
    'Z shell',
]

NOSQL = [
    'Aerospike',
    'Aerospike',
    'AllegroGraph',
    'Apache Cassandra',
    'CouchDB',
    'Couchbase',
    'Hyperdex',
    'InfiniteGraph',
    'MUMPS',
    'MemcacheDB',
    'Memcached',
    'MongoDB',
    'Neo4J',
    'Redis',
    'RethinkDB',
    'Riak',
]

SQL = [
    'MariaDB',
    'MySQL',
    'PostgreSQL',
    'Oracle DB',
    'SQLite',
    'DB2',
]

BACKEND = [
    'C#/ASP.NET',
    'Java',
    'Java/Tapestry',
    'Go/Beego',
    'Python/Bottle',
    'Python/CherryPy',
    'Erlang',
    'Erlang/ChicagoBoss',
    'Erlang/Cowboy',
    'Clojure',
    'Django',
    'Python/Django',
    'Python/Flask/Gunicorn',
    'Elixir/Phoenix',
    'Node/Express',
    'Python/Falcon',
    'Python/Flask',
    'Go/Gin',
    'Go/Martini',
    'Go/Gorilla',
    'Groovy/Grails',
    'PHP/Laravel',
    'Java/Ninja',
    'PHP/Yii 2',
    'Pyramid',
    'Python/Pyramid',
    'Python/SQLAlchemy',
    'Python/Twisted',
    'Python/web2py',
    'Go/Revel',
    'Ruby on Rails',
    'Ruby/Sinatra',
    'Java/Spring',
    'PHP/Symfony',
    'Python/Tornado',
    'PHP/Zend Framework',
]

FRONTEND = [
    'JavaScript/Angular 2',
    'JavaScript/Backbone',
    'Gulp/Bower/Sass',
    'JS/HTML/CSS/Canvas/SVG',
    'JavaScript/Ember',
    'JavaScript/React',
    'JavaScript/React/Redux',
    'JavaScript/React/Redux/Flux',
    'JS/HTML/CSS',
    'JavaScript/Highcharts.js',
    'JS/Twitter Bootstrap',
    'React/Canvas/SVG',
    'React/D3.js',
    'React/Redux/Babel',
    'JavaScript/Reflux/Redux',
    'JS/Sass/Less/Gulp',
    'Stylus/Sass/Webpack',
    'JavaScript/Vue',
    'JavaScript/jQuery',
    'TypeScript/React',
    'TypeScript/CSS/HTML',
    'Webpack/Grunt/PostCSS',
]

OS = [
    'Arch',
    'CentOS',
    'Debian',
    'Fedora',
    'FreeBSD',
    'Gentoo',
    'Kali',
    'Lubuntu',
    'Manjaro',
    'Mint',
    'OS X',
    'OpenBSD',
    'PCLinuxOS',
    'Slackware',
    'Ubuntu',
    'Windows 10',
    'Windows 7',
    'Windows 8',
    'Windows 8.1',
    'Zorin',
    'elementaryOS',
    'macOS',
    'openSUSE',
]

FOLDERS = [
    'Development',
    'Downloads',
    'Documents',
    'Music',
    'Video',
    'Work',
    'Pictures',
    'Desktop',
    'Study',
]

PROJECT_NAMES = [
    'aardonyx',
    'abelisaurus',
    'achelousaurus',
    'achillobator',
    'acrocanthosaurus',
    'aegyptosaurus',
    'afrovenator',
    'agilisaurus',
    'alamosaurus',
    'albertaceratops',
    'albertosaurus',
    'alectrosaurus',
    'alioramus',
    'allosaurus',
    'alvarezsaurus',
    'amargasaurus',
    'ammosaurus',
    'ampelosaurus',
    'amygdalodon',
    'anatotitan',
    'anchiceratops',
    'anchisaurus',
    'ankylosaurus',
    'anserimimus',
    'antarctopelta',
    'antarctosaurus',
    'apatosaurus',
    'aragosaurus',
    'aralosaurus',
    'archaeoceratops',
    'archaeopteryx',
    'archaeornithomimus',
    'argentinosaurus',
    'arrhinoceratops',
    'atlascopcosaurus',
    'aucasaurus',
    'austrosaurus',
    'avaceratops',
    'avalonia',
    'avimimus',
    'azendohsaurus',
    'bactrosaurus',
    'bagaceratops',
    'bambiraptor',
    'barapasaurus',
    'barosaurus',
    'baryonyx',
    'becklespinax',
    'beipiaosaurus',
    'bellusaurus',
    'borogovia',
    'brachiosaurus',
    'brachyceratops',
    'bugenasaura',
    'buitreraptor',
    'camarasaurus',
    'camptosaurus',
    'carnotaurus',
    'caudipteryx',
    'cedarpelta',
    'centrosaurus',
    'ceratosaurus',
    'cetiosauriscus',
    'cetiosaurus',
    'chaoyangsaurus',
    'chasmosaurus',
    'chialingosaurus',
    'chindesaurus',
    'chinshakiangosaurus',
    'chirostenotes',
    'chubutisaurus',
    'chungkingosaurus',
    'citipati',
    'coelophysis',
    'coelurus',
    'coloradisaurus',
    'compsognathus',
    'conchoraptor',
    'confuciusornis',
    'corythosaurus',
    'cryolophosaurus',
    'dacentrurus',
    'daspletosaurus',
    'datousaurus',
    'deinocheirus',
    'deinonychus',
    'deltadromeus',
    'diceratops',
    'dicraeosaurus',
    'dilophosaurus',
    'diplodocus',
    'dracorex',
    'dravidosaurus',
    'dromaeosaurus',
    'dromiceiomimus',
    'dryosaurus',
    'dryptosaurus',
    'dubreuillosaurus',
    'edmontonia',
    'edmontosaurus',
    'einiosaurus',
    'elaphrosaurus',
    'emausaurus',
    'eolambia',
    'eoraptor',
    'eotyrannus',
    'equijubus',
    'erketu',
    'erlikosaurus',
    'euhelopus',
    'euoplocephalus',
    'europasaurus',
    'euskelosaurus',
    'eustreptospondylus',
    'fukuiraptor',
    'fukuisaurus',
    'gallimimus',
    'gargoyleosaurus',
    'garudimimus',
    'gasosaurus',
    'gasparinisaura',
    'gastonia',
    'giganotosaurus',
    'gilmoreosaurus',
    'giraffatitan',
    'gobisaurus',
    'gorgosaurus',
    'goyocephale',
    'graciliceratops',
    'gryposaurus',
    'guaibasaurus',
    'guanlong',
    'hadrosaurus',
    'hagryphus',
    'haplocanthosaurus',
    'harpymimus',
    'herrerasaurus',
    'hesperosaurus',
    'heterodontosaurus',
    'homalocephale',
    'huayangosaurus',
    'hylaeosaurus',
    'hypacrosaurus',
    'hypselosaurus',
    'hypsilophodon',
    'iguanodon',
    'indosuchus',
    'ingenia',
    'irritator',
    'isisaurus',
    'janenschia',
    'jaxartosaurus',
    'jingshanosaurus',
    'jinzhousaurus',
    'jobaria',
    'juravenator',
    'kentrosaurus',
    'khaan',
    'kotasaurus',
    'kritosaurus',
    'lamaceratops',
    'lambeosaurus',
    'lapparentosaurus',
    'leaellynasaura',
    'leptoceratops',
    'lesothosaurus',
    'lexovisaurus',
    'liaoceratops',
    'liaoxiornis',
    'ligabuesaurus',
    'liliensternus',
    'lophorhothon',
    'lophostropheus',
    'lufengosaurus',
    'lurdusaurus',
    'lycorhinus',
    'magyarosaurus',
    'maiasaura',
    'majungatholus',
    'malawisaurus',
    'mamenchisaurus',
    'mapusaurus',
    'marshosaurus',
    'masiakasaurus',
    'massospondylus',
    'maxakalisaurus',
    'megalosaurus',
    'melanorosaurus',
    'metriacanthosaurus',
    'microceratops',
    'micropachycephalosaurus',
    'microraptor',
    'minmi',
    'monolophosaurus',
    'mononykus',
    'mussaurus',
    'muttaburrasaurus',
    'nanotyrannus',
    'nanshiungosaurus',
    'nemegtosaurus',
    'neovenator',
    'neuquenosaurus',
    'nigersaurus',
    'nipponosaurus',
    'noasaurus',
    'nodosaurus',
    'nomingia',
    'nothronychus',
    'nqwebasaurus',
    'omeisaurus',
    'ornitholestes',
    'ornithomimus',
    'orodromeus',
    'oryctodromeus',
    'othnielia',
    'ouranosaurus',
    'oviraptor',
    'rebbachisaurus',
    'rhabdodon',
    'rhoetosaurus',
    'rinchenia',
    'riojasaurus',
    'rugops',
    'saichania',
    'saltasaurus',
    'saltopus',
    'sarcosaurus',
    'saurolophus',
    'sauropelta',
    'saurophaganax',
    'saurornithoides',
    'scelidosaurus',
    'scutellosaurus',
    'secernosaurus',
    'segisaurus',
    'segnosaurus',
    'seismosaurus',
    'shamosaurus',
    'shanag',
    'shantungosaurus',
    'shunosaurus',
    'shuvuuia',
    'silvisaurus',
    'sinocalliopteryx',
    'sinornithosaurus',
    'sinosauropteryx',
    'sinraptor',
    'sinvenator',
    'zalmoxes',
    'zephyrosaurus',
    'zuniceratops',
    'byzantine',
    'svengali',
    'accolade',
    'acrimony',
    'angst',
    'anomaly',
    'antidote',
    'baroque',
    'bona_fide',
    'bourgeois',
    'bravado',
    'brogue',
    'brusque',
    'cacophony',
    'caustic',
    'charisma',
    'cloying',
    'deja-vu',
    'dichotomy',
    'elan',
    'ennui',
    'epitome',
    'esoteric',
    'euphemism',
    'faux pas',
    'fiasco',
    'finagle',
    'glib',
    'harbinger',
    'hedonist',
    'heresy',
    'idyllic',
    'insidious',
    'junket',
    'kitsch',
    'litany',
    'lurid',
    'malaise',
    'malinger',
    'mantra',
    'maudlin',
    'mercenary',
    'misnomer',
    'nirvana',
    'oblivion',
    'ogle',
    'ostracize',
    'panacea',
    'paradox',
    'peevish',
    'propriety',
    'revel',
    'rhetoric',
    'spartan',
    'stigma',
    'stoic',
    'suave',
    'sycophant',
    'tirade',
    'tryst',
    'untenable',
    'vicarious',
    'vile',
    'waft',
    'zealous',
]
